@extends('layouts.app-guest')
@section('title', __('auth.login'))
@section('content')
<div class="card-body">
    <div class="text-center mb-5">
        <img src="{{url('assets/images/favicon.svg')}}" height="100" class='mb-4'>
        <h3>{{ __('auth.login') }}</h3>
    </div>
    <x-auth-session-status class="mb-4" :status="session('status')" />

    <form method="POST" action="{{ route('login', ['locale' => app()->getLocale()]) }}">
        @csrf

        <!-- Company -->
        <div class="form-group position-relative has-icon-left">
            <div class="position-relative">
                <x-input-label for="company_id" :value="__('auth.company_type_filter_list')" />
                <select id="company_id" name="company_id" class="block mt-1 w-full form-control">
                    @foreach($Companies as $company)
                    <option value="{{ $company->id }}">{{ $company->name}}</option>
                    @endforeach
                </select>
                <x-input-error :messages="$errors->get('id')" class="mt-2 form-control" />
            </div>
        </div>

        <!-- Email or Username -->
        <div class="form-group position-relative has-icon-left">
            <div class="position-relative">
                <div class="form-control-icon">
                    <i data-feather="key"></i>
                </div>
                <x-input-label for="input_type" :value="__('auth.email_or_username')" />
                <x-text-input id="input_type" class="block mt-1 w-full form-control" type="text" name="input_type" :value="old('input_type')" required autofocus autocomplete="username" />
                <x-input-error :messages="$errors->get('email')" class="mt-2 form-control" />
                <x-input-error :messages="$errors->get('username')" class="mt-2 form-control" />
            </div>
        </div>

        <!-- Password -->
        <div class="form-group position-relative has-icon-left">
            <div class="position-relative">
                <div class="form-control-icon">
                    <i data-feather="lock"></i>
                </div>
                <x-input-label for="password" :value="__('auth.password')" />
                <x-text-input id="password" class="block mt-1 w-full form-control" type="password" name="password" required autocomplete="current-password" />
                <x-input-error :messages="$errors->get('password')" class="mt-2 form-control" />
            </div>
        </div>

        <div class="flex items-center justify-end mt-4">
            @if (Route::has('password.request'))
            <a class="underline text-sm text-gray-600 text-gray-400 hover:text-gray-900 hover:text-gray-100 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 focus:ring-offset-gray-800" href="{{ route('password.request', ['locale' => app()->getLocale()]) }}">
                {{ __('auth.forgot_your_password') }}
            </a>
            @endif
        </div>

        <!-- Remember Me -->
        <div class='form-check clearfix my-4'>
            <div class="block mt-1 checkbox float-left">
                <label for="remember_me" class="inline-flex items-center">
                    <input id="remember_me" type="checkbox" class=" rounded   bg-gray-900 border-gray-300   border-gray-700 text-indigo-600 shadow-sm focus:ring-indigo-500  focus:ring-indigo-600   focus:ring-offset-gray-800" name="remember">
                    <span class="ms-2 text-sm text-gray-600   text-gray-400">{{ __('auth.remember_me') }}</span>
                </label>
            </div>


            <div class="clearfix">
                <x-primary-button class="ms-4 btn btn-primary float-right">
                    {{ __('auth.log_in') }}
                </x-primary-button>
            </div>


        </div>
    </form>
</div>
<div class="divider">
    <div class="divider-text">{{ __('auth.or') }}</div>
</div>
<div class="row px-4 pb-3">
    <div class="col-sm-6">
        <button class="btn btn-block mb-2 btn-primary"><i data-feather="facebook"></i> Facebook</button>
    </div>
    <div class="col-sm-6">
        <button class="btn btn-block mb-2 btn-secondary"><i data-feather="linkedin"></i> Linkedin</button>
    </div>
</div>
@endsection