<form action="{{ route('devices.update', [$locale, 'device' => $device]) }}" method="POST" enctype="multipart/form-data">
    @csrf
    @method('PUT')
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="device_id">{{ __('devices.form.label.device_id') }}</label>
                <input type="text" class="form-control" id="device_id" name="device_id" value="{{$device->device_id}}" required>
                @error("device_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="icon_id">{{ __('devices.form.label.icon') }}</label>
                <select class="form-control" id="icon_id" name="icon_id" required>
                    @foreach ($icons as $icon)
                        <option value="{{ $icon->id }}" {{ $icon->id == $device->icon_id ? 'selected' : '' }}>{{ $icon->description }}</option>
                    @endforeach
                </select>
                @error("icon_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="energy_id">{{ __('devices.form.label.energy') }}</label>
                <select class="form-control" id="energy_id" name="energy_id" required>
                    <option value="">{{ __('devices.form.label.choose_energy') }}</option>
                    @foreach ($energies as $energy)
                        <option value="{{ $energy->id }}" {{ $energy->id == $device->energy_id ? 'selected' : '' }}>{{ $energy->label }}</option>
                    @endforeach
                </select>
                @error("energy_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="position_id">{{ __('devices.form.label.position') }}</label>
                <select class="form-control" id="position_id" name="position_id" required>
                    <option value="">{{ __('devices.form.label.choose_position') }}</option>
                    @foreach ($positions as $position)
                        <option value="{{ $position->id }}" {{ $position->id == $device->position_id ? 'selected' : '' }}>{{ $position->label }}</option>
                    @endforeach
                </select>
                @error("position_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="description">{{ __('devices.form.label.description') }}</label>
                <textarea class="form-control" id="description" name="description" required>{{$device->description}}</textarea>
                @error("description")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="emplacement">{{ __('devices.form.label.emplacement') }}</label>
                <input type="text" class="form-control" id="emplacement" name="emplacement" value="{{$device->emplacement}}" required>
                @error("emplacement")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="instruction_id">{{ __('devices.form.label.instruction') }}</label>
                <select class="form-control" id="instruction_id" name="instruction_id" required>
                    <option value="">{{ __('devices.form.label.choose_instruction') }}</option>
                    @foreach ($instructions as $instruction)
                        <option value="{{ $instruction->id }}" {{ $instruction->id == $device->instruction_id ? 'selected' : '' }}>{{ $instruction->label }}</option>
                    @endforeach
                </select>
                @error("instruction_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            @if ($device->image)
                <img src="{{ $device->image }}" alt="Image du dispositif" class="img-fluid mb-3">
            @endif
            <div class="form-group mb-3">
                <label for="image">{{ __('devices.form.label.image') }}</label>
                <input type="file" class="form-control" id="image" name="image" value="">
                @error("image")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <input type="checkbox" class="form-check-input" id="need_lockpad" name="need_lockpad" value="{{$device->need_lockpad}}">
                <label for="need_lockpad">{{ __('devices.form.label.need_lockpad') }}</label>
                @error("need_lockpad")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="mechanism_id">{{ __('devices.form.label.mechanism') }}</label>
                <select class="form-control" id="mechanism_id" name="mechanism_id">
                    <option value="">{{ __('devices.form.label.choose_mechanism') }}</option>
                    @foreach ($mechanisms as $mechanism)
                        <option value="{{ $mechanism->id }}" {{ $mechanism->id == $device->mechanism_id ? 'selected' : '' }}>{{ $mechanism->type }}</option>
                    @endforeach
                </select>
                @error("mechanism_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="position_decad_id">{{ __('devices.form.label.position_decad') }}</label>
                <select class="form-control" id="position_decad_id" name="position_decad_id" required>
                    <option value="">{{ __('devices.form.label.choose_position_decad') }}</option>
                    @foreach ($positions as $position)
                        <option value="{{ $position->id }}" {{ $position->id == $device->position_decad_id ? 'selected' : '' }}>{{ $position->label }}</option>
                    @endforeach
                </select>
                @error("position_decad_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md6">
            <input class="btn btn-primary" type="submit" name="valider" value="Valider" >
            <a href="{{ route('devices.index', $locale)  }}" class="btn btn-secondary">Annuler</a>
        </div>
    </div>
</form>
