@extends('layouts.app-bo')
@section('title', __('devices.device_management'))

@section('content')

    <div class="main-content container-fluid">
        <section class="section">
            <div class="card" id="training-demand">
                <div class="card-body">
                    <div class="d-md-flex align-items-center justify-content-between">
                        <div class="mb-4 mb-md-0">
                            <h4 class="card-title">
                                <iconify-icon icon="material-symbols-light:flowsheet-outline"></iconify-icon>
                                {{ __("devices.device_management") }}
                            </h4>
                            <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($devices) }}</b> {{ __('devices.items') }}</div>
                        </div>
                        <div class="d-flex align-items-center justify-content-between gap-6 mb-2">
                            <a href="{{ route('devices.create', [$locale]) }}" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9">
                                <i class="ti ti-plus fs-4"></i>
                                {{ __("app.button.add") }}
                            </a>
                        </div>
                    </div>
                    <div class="{{ $setting->table_div_class }}">
                        <table class="table mb-0 table-hover display">
                            <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("devices.table.id") }}</th>
                                <th>{{ __("devices.table.device_id") }}</th>
                                <th width="15%">{{ __("devices.table.description") }}</th>
                                <th>{{ __("devices.table.icon") }}</th>
                                <th width="5%">{{ __("devices.table.energy") }}</th>
                                <th width="10%">{{ __("devices.table.emplacement") }}</th>
                                <th width="5%">{{ __("devices.table.position") }}</th>
                                <th width="20%">{{ __("devices.table.instruction") }}</th>
                                <th width="5%">{{ __("devices.table.image") }}</th>
                                <th width="5%">{{ __("devices.table.position_decad") }}</th>
                                <th>{{ __("devices.table.need_lockpad") }}</th>
                                <th>{{ __("devices.table.mechanism") }}</th>
                                <th class="sticky-search-button table-actions">{{ __("app.actions") }}</th>
                            </tr>
                            </thead>
                            <tbody class="{{ $setting->table_tbody_class }}">
                                @foreach ($devices as $key => $device)
                                    <tr>
                                        <td>{{ $key+1 }}</td>
                                        <td>{{ $device->id }}</td>
                                        <td>{{ $device->device_id }}</td>
                                        <td>{{ $device->description }}</td>
                                        <td><img src="{{ $device->icon?->icon }}" alt="{{ $device->icon?->icon }}" title="{{ $device->icon?->title }}" class="img-fluid" style="max-width: 50px;"></td>
                                        <td>{{ $device->energy->label }}</td>
                                        <td>{{ $device->emplacement }}</td>
                                        <td>{{ $device->position?->label }}</td>
                                        <td>{{ $device->instruction?->label }}</td>
                                        <td><img src="{{ $device->image }}" alt="{{ $device->image }}" title="{{ $device->image }}" class="img-fluid" style="max-width: 50px;"></td>
                                        <td>{{ $device->position_decad?->label }}</td>
                                        <td>{!! $device->need_lockpad ? '<iconify-icon icon="ph:check-bold" style="font-size: 24px; color: green;"></iconify-icon>' : '<iconify-icon icon="ph:x-bold" style="font-size: 24px; color: red;"></iconify-icon>' !!}</td>
                                        <td>
                                            <img src="{{ $device->mechanism->icon }}" alt="{{ $device->mechanism->type }}" title="{{ $device->mechanism->title }}" class="img-fluid" style="max-width: 50px;">
                                        </td>
                                        <td class="sticky-search-button">
                                            <a href="{{ route('devices.show', [$locale, 'device' => $device]) }}" class="text-primary view" title="{{ __('app.button.title.show') }}">
                                                <i class="ti ti-eye fs-5"></i>
                                            </a>
                                            <a href="{{ route('devices.edit', [$locale, 'device' => $device]) }}" class="text-primary check" title="{{ __('app.button.title.edit') }}">
                                                <i class="ti ti-edit fs-5 text-success"></i>
                                            </a>
                                            <form action="{{ route('devices.destroy', [$locale, 'device' => $device]) }}" method="POST" class="d-inline">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit" class="btn btn-link p-0" onclick="return confirm('{{ __('device_icons.message.confirm.delete') }}')">
                                                    <i class="ti ti-trash fs-5 text-danger" title="{{ __('app.button.title.delete') }}"></i>
                                                </button>
                                            </form>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                    <div class="row">
                        <div class="col-12 mt-3">
                            {{ $devices->links() }}
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>
@endsection
