<form action="{{ route('lockouts.update', [$locale, 'lockout' => $lockout]) }}" method="POST" enctype="multipart/form-data">
    @csrf
    @method('PUT')
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="equipment_id" class="form-label">{{ __('lockouts.form.label.equipment_id') }}</label>
                <input type="text" class="form-control" id="equipment_id" name="equipment_id" value="{{ $lockout->equipment_id }}" required>
                @error("equipment_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="equipment_description" class="form-label">{{ __('lockouts.form.label.equipment_description') }}</label>
                <textarea class="form-control" id="equipment_description" name="equipment_description" rows="3" required>{{ $lockout->equipment_description }}</textarea>
                @error("description")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="equipment_image">{{ __('lockouts.form.label.equipment_image') }}</label>
                <input type="file" class="form-control" id="equipment_image" name="equipment_image" value="{{ $lockout->equipment_image }}" onchange="previewImage(this)">
                @if ($lockout->equipment_image)
                    <img id="preview" src="{{ $lockout->equipment_image }}" alt="Image actuelle" class="img-thumbnail" style="max-width: 200px; margin-top: 10px;">
                @endif
                @error("equipment_image")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="code" class="form-label">{{ __('lockouts.form.label.code') }}</label>
                <input type="text" class="form-control" id="code" name="code" value="{{ $lockout->code }}" required>
                @error("code")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="version" class="form-label">{{ __('lockouts.form.label.version') }}</label>
                <input type="text" class="form-control" id="version" name="version" value="{{ $lockout->version }}" required>
                @error("version")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="equipment_location" class="form-label">{{ __('lockouts.form.label.equipment_location') }}</label>
                <input type="text" class="form-control" id="equipment_location" name="equipment_location" value="{{ $lockout->equipment_location }}" required>
                @error("equipment_location")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="title" class="form-label">{{ __('lockouts.form.label.title') }}</label>
                <input type="text" class="form-control" id="title" name="title" value="{{ $lockout->title }}" required>
                @error("title")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="department_id" class="form-label">{{ __('lockouts.form.label.department') }}</label>
                <select class="form-control" id="department_id" name="department_id" required>
                    @foreach ($departments as $department)
                        <option value="{{ $department->id }}" {{ $department->id == $lockout->department_id ? 'selected' : '' }}>{{ $department->name }}</option>
                    @endforeach
                </select>
                @error("department_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="sub_department_id" class="form-label">{{ __('lockouts.form.label.sub_department') }}</label>
                <select class="form-control" id="sub_department_id" name="sub_department_id" required>
                    @foreach ($subDepartments as $subDepartment)
                        <option value="{{ $subDepartment->id }}" {{ $subDepartment->id == $lockout->sub_department_id ? 'selected' : '' }}>{{ $subDepartment->name }}</option>
                    @endforeach
                </select>
                @error("sub_department_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-6">
            <div class="form-group mb-3">
                <label for="location_id" class="form-label">{{ __('lockouts.form.label.location') }}</label>
                <select class="form-control" id="location_id" name="location_id" required>
                    @foreach ($locations as $location)
                        <option value="{{ $location->id }}" {{ $location->id == $lockout->location_id ? 'selected' : '' }}>{{ $location->name }}</option>
                    @endforeach
                </select>
                @error("location_id")
                <div>{{ $message }}</div>
                @enderror
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-md6">
            <input class="btn btn-primary" type="submit" name="valider" value="Valider" >
            <a href="{{ route('lockouts.index', $locale)  }}" class="btn btn-secondary">Annuler</a>
        </div>
    </div>
</form>

<script>
    function previewImage(input) {
        const $preview = $('#preview');
        if (input.files && input.files[0]) {
            const reader = new FileReader();
            reader.onload = function(e) {
                $preview.attr('src', e.target.result)
                       .show();
            }
            reader.readAsDataURL(input.files[0]);
        } else {
            $preview.attr('src', '#')
                   .hide();
        }
    }
</script>
