@extends('layouts.app-bo')

@section('title', __('other.dashboard'))

@section('content')
<div class="main-content container-fluid">
    <div class="page-title">
        <div class="row">
            <div class="col-12 col-md-6 order-md-1 order-last">
                <h3>{{ __('users.service') }}</h3>
            </div>
        </div>
    </div>

    <section class="section">
        <div class="card">
            <div class="card-header">
                <a class="btn btn-outline-success" href="{{ route('competencyservice.create', ['locale' => app()->getLocale()]) }}">
                    {{ __('other.create') }} {{ __('users.service') }}
                </a>
            </div>
            <div class="card-body table-responsive">
                <table id="default_order" class="table table-striped table-bordered display text-nowrap">
                    <thead>
                        <tr>
                            <th>#</th>
                            <th>{{ __('other.name') }} {{ __('users.service') }}</th>
                            <th>{{ __('users.competency') }}</th>
                            <th>{{ __('other.action') }}</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($services as $location)
                        <tr>
                            <td>{{ $location->id }}</td>
                            <td>{{ $location->name }}</td>
                            <td>{{ $location->competencies->name }}</td>
                            <td>
                                <div class="btn-location" role="group" aria-label="Service Actions">
                                    <a href="#" class="btn icon btn-warning" title="Edit" data-bs-toggle="modal" data-bs-target="#edit-location-modal-{{ $location->id }}">
                                        <!-- Icone de modification -->
                                        <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="16" height="16">
                                            <path d="M20.71 7.04l-3.75-3.75c-.78-.78-2.05-.78-2.83 0L2.29 16.29c-.39.39-.6.91-.6 1.46v4.25c0 .41.34.75.75.75h4.25c.55 0 1.07-.21 1.46-.6L20.71 9.87c.39-.39.6-.91.6-1.46v-4.25c0-.41-.34-.75-.75-.75zm-13.16 12.52l-1.85.62.62-1.85 9.33-9.33 1.23 1.23-9.33 9.33z" />
                                        </svg>
                                    </a>&nbsp;
                                    <form action="{{ route('competencyservice.destroy', ['locale' => app()->getLocale(), 'id' => $location->id]) }}" method="POST" style="display: inline;">
                                        @csrf
                                        @method('DELETE')
                                        <button type="submit" class="btn icon btn-danger" title="Delete" onclick="return confirm('Are you sure you want to delete this item?');">
                                            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="16" height="16">
                                                <path d="M19 5h-4.2l-.8-1H9.97l-.8 1H5v2h14V5zm-3 12H8l-.6-7.6h10.3L16 17zm-2.25-8.75c0 .41-.34.75-.75.75s-.75-.34-.75-.75V7c0-.41.34-.75.75-.75s.75.34.75.75v1.25zm-3.5 0c0 .41-.34.75-.75.75s-.75-.34-.75-.75V7c0-.41.34-.75.75-.75s.75.34.75.75v1.25zm6.5 0c0 .41-.34.75-.75.75s-.75-.34-.75-.75V7c0-.41.34-.75.75-.75s.75.34.75.75v1.25z" />
                                            </svg>
                                        </button>
                                    </form>
                                </div>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </section>
</div>

@foreach($services as $location)
<!-- Edit Location Modal -->
<div class="modal fade" id="edit-location-modal-{{ $location->id }}" tabindex="-1" role="dialog" aria-labelledby="editLocationModalLabel-{{ $location->id }}" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered modal-dialog-scrollable" role="document">
        <div class="modal-content">
            <div class="modal-header bg-warning">
                <h5 class="modal-title white" id="editLocationModalLabel-{{ $location->id }}">
                    {{ __('other.update') }} {{ __('users.service') }}
                </h5>
                <button type="button" class="btn-close btn-close-red" data-bs-dismiss="modal" aria-label="Close">
                </button>
            </div>
            <div class="modal-body">
                <form method="post" action="{{ route('competencyservice.update', ['locale' => app()->getLocale(), 'id' => $location->id]) }}" enctype="multipart/form-data">
                    @csrf
                    @method('PUT')
                    <div class="mb-3">
                        <label for="competence" class="form-label">{{ __('users.competency') }}</label>
                        <select class="form-select" name="competence" aria-describedby="competenceHelp">
                            @foreach($competencies as $competency)
                            <option value="{{ $competency->id }}" {{ $location->competency_id == $competency->id ? 'selected' : '' }}>
                                {{ $competency->name }}
                            </option>
                            @endforeach
                        </select>
                    </div>
                    <div class="mb-3">
                        <label for="existingService" class="form-label">{{ __('users.select_formation_exist') }}</label>
                        <select class="form-select" name="existingService">
                            <option {{ $location->id == null ? 'selected' : '' }}>Select a service</option>
                            @foreach($services as $service)
                            <option value="{{ $service->id }}" {{ $location->id == $service->id ? 'selected' : '' }}>
                                {{ $service->name }}
                            </option>
                            @endforeach
                        </select>
                    </div>
                    <div class="mb-3">
                        <label for="newService" class="form-label">{{ __('users.service_name') }}</label>
                        <input type="text" class="form-control" name="newService" value="{{ $location->name }}">
                    </div>
                    <div class="mb-3">
                        <label for="coursePlan" class="form-label">{{ __('users.coursePlan') }}</label>
                        <input type="file" class="form-control" name="coursePlan">
                    </div>
                    <div class="form-group d-flex justify-content-between">
                        <a href="{{ route('competencyservice.list', ['locale' => app()->getLocale()]) }}" class="btn btn-info">
                            <i class="bi bi-arrow-left-circle"></i> {{ __('users.back') }}
                        </a>
                        <button type="submit" class="btn btn-success">{{ __('other.update') }}</button>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-light-secondary" data-bs-dismiss="modal">{{ __('other.close') }}</button>
            </div>
        </div>
    </div>
</div>
@endforeach

@endsection