@extends('layouts.app-bo')
@section('title', __('app.training'))
@section('content')

    <style>
        .progress {
            height: 15px;
            border-radius: 10px;
            box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
        }
        .progress-bar {
            font-size: 12px;
            line-height: 25px;
            transition: width 0.6s ease;
        }
        .card {
            border-radius: 15px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            margin-bottom: 20px;
        }
        .card-body {
            padding: 25px;
        }
        .nav-tabs {
            border-bottom: 2px solid #dee2e6;
        }
        .nav-tabs .nav-link {
            border: none;
            color: #6c757d;
            padding: 10px 20px;
            transition: all 0.3s ease;
        }
        .nav-tabs .nav-link:hover {
            border: none;
            color: #495057;
            background-color: rgba(0,0,0,0.05);
        }
        .nav-tabs .nav-link.active {
            color: #0d6efd;
            border: none;
            border-bottom: 2px solid #0d6efd;
        }
        h3 {
            color: #2c3e50;
            font-weight: 600;
        }
        h4 {
            color: #34495e;
            margin-bottom: 20px;
        }
        h4 a {
            text-decoration: none;
            transition: color 0.3s ease;
        }
        h4 a:hover {
            color: #0d6efd;
        }
        .mb-2, .mb-3 {
            margin-bottom: 1.5rem !important;
        }
        hr.border-dark {
            opacity: 0.15;
        }
    </style>

    <div class="main-content container-fluid">
        <section>
            <div class="card mb-3">
                @php
                    $trainee = App\Models\User::find($trainee_id);
                @endphp
                <div class="card-body">
                    <h3>{{ __('app.trainee') }}: {{ $trainee->fname }} {{ $trainee->lname }}</h3>
                </div>
            </div>
            <div class="card">
                <div class="card-body">
                    <ul class="nav nav-tabs" id="categoryTabs" role="tablist">
                        @foreach($categories as $category)
                            <li class="nav-item" role="presentation">
                                <button class="nav-link small"
                                        id="tab-{{ $category->id }}"
                                        data-bs-toggle="tab"
                                        data-bs-target="#content-{{ $category->id }}"
                                        type="button"
                                        role="tab"
                                        aria-controls="content-{{ $category->id }}"
                                        aria-selected="{{ $loop->first ? 'true' : 'false' }}">
                                    <small>{{ $category->new_name }}</small>
                                </button>
                            </li>
                        @endforeach
                    </ul>
                </div>
            </div>
            <div class="card">
                <div class="card-body">
                    <div class="tab-content mt-3 col-10 mx-auto" id="categoryTabsContent">
                        @foreach($categories as $category)
                            <div class="tab-pane fade {{ $loop->first ? 'show active' : '' }}"
                                 id="content-{{ $category->id }}"
                                 role="tabpanel"
                                 aria-labelledby="tab-{{ $category->id }}">

                                @if($category->id == 3)
                                    @if(empty($trainings))
                                        <h4>{{ __('Nothing assigned') }}</h4>
                                    @else
                                        @foreach($trainings as $training)
                                            @php
                                                $progress=App\Models\UserTraining::calculateProgress($training->user_training_id);
                                            @endphp

                                            <h4>
                                                <a href="{{ route('user-training.manage-trainee', [$locale, $training->id]) }}">
                                                    {{ $training->name }}
                                                </a>
                                            </h4>

                                            <div class="mb-3">
                                                {{ __('Progress') }} (A): {{ round($progress['progress_a'], 2) }}%
                                                <div class="progress">
                                                    <div class="progress-bar bg-success" role="progressbar"
                                                         style="width: {{ $progress['progress_a'] }}%"
                                                         aria-valuenow="{{ $progress['progress_a'] }}"
                                                         aria-valuemin="0"
                                                         aria-valuemax="100">
                                                        {{ round($progress['progress_a'], 2) }}%
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="mb-3">
                                                {{ __('Progress') }} (I): {{ round($progress['progress_i'], 2) }}%
                                                <div class="progress">
                                                    <div class="progress-bar bg-success" role="progressbar"
                                                         style="width: {{ $progress['progress_i'] }}%"
                                                         aria-valuenow="{{ $progress['progress_i'] }}"
                                                         aria-valuemin="0"
                                                         aria-valuemax="100">
                                                        {{ round($progress['progress_i'], 2) }}%
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="mb-3">
                                                {{ __('Progress') }} (S): {{ round($progress['progress_s'], 2) }}%
                                                <div class="progress">
                                                    <div class="progress-bar bg-success" role="progressbar"
                                                         style="width: {{ $progress['progress_s'] }}%"
                                                         aria-valuenow="{{ $progress['progress_s'] }}"
                                                         aria-valuemin="0"
                                                         aria-valuemax="100">
                                                        {{ round($progress['progress_s'], 2) }}%
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="mb-2">
                                                <b>{{ __('Supervisors') }}:</b>
                                                @foreach($supervisors as $supervisor)
                                                    @if($supervisor->is_primary)
                                                        <u>{{ $supervisor->fname }} {{ $supervisor->lname }}</u>{{ !$loop->last ? ',' : '' }}
                                                    @else
                                                        {{ $supervisor->fname }} {{ $supervisor->lname }}{{ !$loop->last ? ',' : '' }}
                                                    @endif
                                                @endforeach
                                            </div>

                                            <div class="mb-3">
                                                <b>{{ __('Instructors') }}:</b>
                                                @foreach($instructors as $instructor)
                                                    @if($instructor->is_primary)
                                                        <u>{{ $instructor->fname }} {{ $instructor->lname }}</u>{{ !$loop->last ? ',' : '' }}
                                                    @else
                                                        {{ $instructor->fname }} {{ $instructor->lname }}{{ !$loop->last ? ',' : '' }}
                                                    @endif
                                                @endforeach
                                            </div>

                                            <hr class="border-dark border-1">
                                        @endforeach
                                    @endif
                                @else
                                    @php
                                        $categoryTrainings = $Othertrainings->where('category_id', $category->id);
                                    @endphp

                                    @if($categoryTrainings->isEmpty())
                                        <h4>{{ __('Nothing assigned') }}</h4>
                                    @else
                                        @foreach($categoryTrainings as $training)
                                            <h4>{{ $training->name }}</h4>
                                            @php
                                                $progress=App\Models\UserTraining::calculateProgress($training->user_training_id);
                                            @endphp
                                            <div class="mb-3">
                                                {{ __('Progress') }}: {{ round($progress['progress_a'], 2) }}%
                                            </div>
                                            <hr class="border-dark border-1">
                                        @endforeach
                                    @endif
                                @endif
                            </div>
                        @endforeach
                    </div>
                </div>
            </div>
        </section>
    </div>

    @include('lib.training-confirm-dialog')
@endsection
