@extends('layouts.app-bo')

@section('title', __('profile.title'))

@section('content')

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Profile</title>
    <style>
        .avatar-selection img {
            width: 100px;
            height: 100px;
            cursor: pointer;
            border: 2px solid transparent;
        }

        .avatar-selection input[type="radio"] {
            display: none;
        }

        .avatar-selection input[type="radio"]:checked+img {
            border: 2px solid blue;
        }
    </style>
</head>
<div class="main-content container-fluid">
    <div class="page-title text-left">
        {{-- title for user profile page --}}
        <h3>{{ __('profile.title') }}</h3>
    </div>
    <div class="card">
        <div class="card-body">
            <div class="tab-pane fade show active" id="pills-account" role="tabpanel" aria-labelledby="pills-account-tab" tabindex="0">
                <div class="row">
                    <div class="col-lg-6 d-flex align-items-stretch">
                        <div class="card w-100 border position-relative overflow-hidden">
                            <div class="card-body p-4">
                                <h4 class="card-title">{{ __('profile.change_profile') }}</h4>
                                <p class="card-subtitle mb-4">{{ __('profile.change_your_profile_picture_from_here') }}</p>
                                <div class="text-center">
                                    <img src="{{ $user->avatar ? asset('/' . $user->avatar) : url('assets/images/profile/user-1.jpg') }}" alt="Profile Image" class="img-fluid rounded-circle" width="120" height="120">
                                    <form method="post" action="{{ route('profile.update', $locale) }}" enctype="multipart/form-data">
                                        @csrf
                                        @method('PATCH')

                                        <div class="form-group">
                                            <div class="avatar-selection">
                                                <h3>{{ __('profile.or_select_a_default_avatar') }}</h3>
                                                @foreach ($defaultAvatars as $avatar)
                                                <label>
                                                    <input type="radio" name="avatar_default" value="{{ basename($avatar) }}">
                                                    <img src="{{ $avatar }}" alt="Default Avatar">
                                                </label>
                                                @endforeach
                                            </div>
                                        </div>
                                        <br>
                                        <input type="file" name="avatar" class="form-control-file">
                                        <button type="submit" class="btn btn-primary">{{ __('profile.save') }}</button>
                                        <p class="mb-0">{{ __('profile.allowed_jpg_gif_or_png_max_size_of_2mb') }}</p>

                                    </form>
                                    @if ($errors->has('avatar'))
                                    <span class="text-danger">{{ $errors->first('avatar') }}</span>
                                    @endif
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6 d-flex align-items-stretch">
                        <div class="card w-100 border position-relative overflow-hidden">
                            <div class="card-body p-4">
                                <section>
                                    <header>
                                        <h2 class="text-lg font-medium text-gray-900">{{ __('profile.update_password') }}</h2>
                                        <p class="mt-1 text-sm text-gray-600">{{ __('profile.ensure_your_account_is_using_a_long_random_password_to_stay_secure') }}</p>
                                    </header>

                                    <form id="form1" method="post" action="{{ route('password.update', $locale) }}" class="mt-6 space-y-6">
                                        @csrf
                                        @method('put')

                                        <div class="mb-3">
                                            <x-input-label class="form-label" for="update_password_current_password" :value="__('profile.current_password')" />
                                            <x-text-input id="update_password_current_password" name="current_password" type="password" class="form-control" autocomplete="current-password" />
                                            <x-input-error :messages="$errors->updatePassword->get('current_password')" class="mt-2" />
                                        </div>
                                        <div class="mb-3">
                                            <x-input-label class="form-label" for="update_password_password" :value="__('profile.new_password')" />
                                            <x-text-input id="update_password_password" name="password" type="password" class="form-control" autocomplete="new-password" />
                                            <x-input-error :messages="$errors->updatePassword->get('password')" class="mt-2" />
                                        </div>
                                        <div>
                                            <x-input-label for="update_password_password_confirmation" :value="__('profile.confirm_password')" />
                                            <x-text-input id="update_password_password_confirmation" name="password_confirmation" type="password" class="form-control" autocomplete="new-password" />
                                            <x-input-error :messages="$errors->updatePassword->get('password_confirmation')" class="mt-2" />
                                        </div>
                                        <br>
                                        <div class="flex items-center gap-4">
                                            <x-primary-button class="btn btn-primary">{{ __('profile.save') }}</x-primary-button>

                                            @if (session('status') === 'password-updated')
                                            <p x-data="{ show: true }" x-show="show" x-transition x-init="setTimeout(() => show = false, 2000)" class="text-sm text-gray-600">{{ __('Saved.') }}</p>
                                            @endif
                                        </div>
                                    </form>
                                </section>
                            </div>
                        </div>
                    </div>
                    <div class="col-12">
                        <div class="card w-100 border position-relative overflow-hidden mb-0">
                            <div class="card-body p-4">
                                <div class="py-12">
                                    <div class="max-w-7xl mx-auto sm:px-6 lg:px-8 space-y-6">
                                        <div class="p-4 sm:p-8 bg-white shadow sm:rounded-lg">
                                            <div class="max-w-xl">
                                                <section>
                                                    <header>
                                                        <h2 class="text-lg font-medium text-gray-900">{{ __('profile.profile_information') }}</h2>
                                                        <p class="mt-1 text-sm text-gray-600">{{ __('profile.update_your_account_s_profile_information_and_email_address') }}</p>
                                                    </header>

                                                    <form id="send-verification" method="post" action="{{ route('verification.send', $locale) }}">
                                                        @csrf
                                                    </form>

                                                    <form id="form2" method="post" action="{{ route('profile.update', $locale) }}" class="mt-6 space-y-6">
                                                        @csrf
                                                        @method('patch')

                                                        <div>
                                                            <x-input-label for="name" :value="__('profile.name')" class="form-label" />
                                                            <x-text-input id="name" name="name" type="text" class="form-control" :value="old('name', $user->name)" required autofocus autocomplete="name" />
                                                            <x-input-error class="mt-2" :messages="$errors->get('name')" />
                                                        </div>

                                                        <div>
                                                            <x-input-label for="email" :value="__('profile.email')" class="form-label" />
                                                            <x-text-input id="email" name="email" type="email" class="form-control" :value="old('email', $user->email)" required autocomplete="username" />
                                                            <x-input-error class="mt-2" :messages="$errors->get('email')" />

                                                            @if ($user instanceof \Illuminate\Contracts\Auth\MustVerifyEmail && ! $user->hasVerifiedEmail())
                                                            <div>
                                                                <p class="text-sm mt-2 text-gray-800">
                                                                    {{ __('profile.your_email_address_is_unverified') }}
                                                                    <button form="send-verification" class="underline text-sm text-gray-600 hover:text-gray-900 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500">
                                                                        {{ __('profile.click_here_to_re_send_the_verification_email') }}
                                                                    </button>
                                                                </p>

                                                                @if (session('status') === 'verification-link-sent')
                                                                <p class="mt-2 font-medium text-sm text-green-600">
                                                                    {{ __('profile.a_new_verification_link_has_been_sent_to_your_email_address') }}
                                                                </p>
                                                                @endif
                                                            </div>
                                                            @endif
                                                        </div>

                                                        <div class="form-group field-id_field required has-error">
                                                            <label class="control-label" for="id_field">{{ __('profile.id_matricule_number') }}</label>
                                                            <input type="text" id="id_field" class="form-control input-lg" name="uid" maxlength="64" aria-required="true" aria-invalid="true" readonly>
                                                        </div>

                                                        <div class="form-group field-already-has-matricule">
                                                            <div class="checkbox">
                                                                <label for="already-has-matricule">
                                                                    <input type="hidden" name="Users[useAutomaticMatricule]" value="0">
                                                                    <input type="checkbox" id="already-has-matricule" name="Users[useAutomaticMatricule]" value="1" onchange="matriculeExists(this);">
                                                                    {{ __('profile.manually_enter_the_matricule_number') }}
                                                                </label>
                                                                <p class="help-block help-block-error"></p>
                                                            </div>
                                                        </div>
                                                    </form>
                                                    <br>
                                                    <div class="flex items-center gap-4">
                                                        <x-primary-button form="form2" class="btn btn-primary">{{ __('profile.save') }}</x-primary-button>

                                                        @if (session('status') === 'profile-updated')
                                                        <p x-data="{ show: true }" x-show="show" x-transition x-init="setTimeout(() => show = false, 2000)" class="text-sm text-gray-600">{{ __('profile.saved') }}</p>
                                                        @endif
                                                    </div>
                                                </section>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <script>
            document.getElementById('submitBtn').addEventListener('click', function() {
                document.getElementById('form1').submit();
                document.getElementById('form2').submit();
            });

            function matriculeExists(checkbox) {
                var idField = document.getElementById('id_field');
                if (checkbox.checked) {
                    idField.removeAttribute('readonly');
                } else {
                    idField.setAttribute('readonly', 'readonly');
                }
            }
        </script>
    </div>
</div>
@endsection