@extends('layouts.app-bo')
@section('title', __('app.my_training'))
@section('content')

    <style>
        #pdf-viewer {
            width: 100%;
            height: auto;
            border: 1px solid #ccc;
            position: relative;
        }

        .toolbar {
            margin-bottom: 10px;
        }

        .toolbar button {
            margin-right: 5px;
        }

        canvas {
            border: 1px solid #000;
            cursor: crosshair;
        }
    </style>

    <div class="container my-5">
        <h1 class="mb-4">Lecture du PDF</h1>

        @php
            $pdfUrl = null; // Initialisation de la variable pour le PDF
        @endphp

        @foreach ($user_trainings as $user_training)
            @php
                $images = $user_training->training->image;
                if (!empty($images)) {
                    $pdfUrl = $images[0]; // On suppose que $images est un tableau ; ajustez si nécessaire
                }
            @endphp
        @endforeach

        <!-- Outils pour le zoom et l'édition -->
        <div class="toolbar">
            <button class="btn btn-primary" id="zoomIn">Zoomer</button>
            <button class="btn btn-secondary" id="zoomOut">Dézoomer</button>
            <button class="btn btn-warning" id="annotate">Annoter</button>
            <button class="btn btn-danger" id="clearAnnotations">Effacer les annotations</button>
        </div>

        <div id="pdf-viewer"></div>

        @if (empty($pdfUrl))
            <p>Aucun PDF n'est disponible.</p>
        @endif
    </div>

    <!-- PDF.js et Bootstrap -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdf.js/2.10.377/pdf.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        let startTime, endTime;
        let pdfDoc = null;
        let currentPage = 1;
        let scale = 1.5; // Échelle de zoom initiale
        let canvas = document.createElement('canvas');
        let context = canvas.getContext('2d');
        let isAnnotating = false;
        const pdfViewer = document.getElementById('pdf-viewer');

        // Démarre le suivi du temps au chargement de la page
        window.onload = function() {
            startTime = new Date().getTime();
        };

        // Fonction pour calculer le temps passé
        function calculateTimeSpent() {
            endTime = new Date().getTime();
            let timeSpent = Math.floor((endTime - startTime) / 1000); // Temps passé en secondes
            return timeSpent;
        }

        // Fonction pour envoyer le temps au serveur via une requête AJAX
        function sendTimeSpent(timeSpent) {
            fetch('/track-time', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'X-CSRF-TOKEN': '{{ csrf_token() }}'
                },
                body: JSON.stringify({ time_spent: timeSpent })
            }).then(response => response.json())
              .then(data => console.log(data));
        }

        // Quand l'utilisateur quitte la page, envoie le temps passé
        window.onbeforeunload = function() {
            let timeSpent = calculateTimeSpent();
            sendTimeSpent(timeSpent);
        };

        // Charger et afficher le PDF
        @if (!empty($pdfUrl))
            const pdfUrl = '{{ asset($pdfUrl) }}'; // Utilisez asset() pour le chemin public
            pdfjsLib.getDocument(pdfUrl).promise.then(function(pdf) {
                pdfDoc = pdf;
                renderPage(currentPage, scale);
            }).catch(function(error) {
                console.error('Erreur lors du chargement du PDF :', error);
            });
        @else
            console.error("Aucun PDF n'est disponible.");
        @endif

        function renderPage(num, scale) {
            pdfDoc.getPage(num).then(function(page) {
                const viewport = page.getViewport({ scale });
                canvas.height = viewport.height;
                canvas.width = viewport.width;

                const renderContext = {
                    canvasContext: context,
                    viewport: viewport
                };
                page.render(renderContext).promise.then(() => {
                    pdfViewer.innerHTML = ''; // Efface tout autre contenu
                    pdfViewer.appendChild(canvas); // Ajoute le canvas contenant le PDF
                });
            });
        }

        // Fonction de zoom
        document.getElementById('zoomIn').addEventListener('click', function() {
            scale += 0.2; // Augmente l'échelle
            renderPage(currentPage, scale);
        });

        document.getElementById('zoomOut').addEventListener('click', function() {
            scale = Math.max(0.5, scale - 0.2); // Diminue l'échelle mais ne va pas en dessous de 0.5
            renderPage(currentPage, scale);
        });

        // Fonction pour activer/désactiver l'annotation
        document.getElementById('annotate').addEventListener('click', function() {
            isAnnotating = !isAnnotating;
            this.textContent = isAnnotating ? 'Arrêter d\'annoter' : 'Annoter';
        });

        // Fonction pour effacer les annotations
        document.getElementById('clearAnnotations').addEventListener('click', function() {
            renderPage(currentPage, scale); // Recharge la page sans les annotations
        });

        // Gestion des annotations avec la souris
        canvas.addEventListener('mousedown', function(e) {
            if (!isAnnotating) return;

            const rect = canvas.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;

            context.strokeStyle = 'red';
            context.lineWidth = 3;
            context.beginPath();
            context.moveTo(x, y);

            canvas.addEventListener('mousemove', draw);
            canvas.addEventListener('mouseup', stopDrawing);
        });

        function draw(e) {
            const rect = canvas.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            context.lineTo(x, y);
            context.stroke();
        }

        function stopDrawing() {
            canvas.removeEventListener('mousemove', draw);
            canvas.removeEventListener('mouseup', stopDrawing);
        }
    </script>
@endsection
