@extends('layouts.app-bo')
@section('title', __("app.activities_for") . ' ' . $assigned_training->training->name)
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __("app.activities_for") }} {{ $assigned_training->training->name }}
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($assigned_training->activities) }}</b> {{ __('app.items') }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="javascript:void(0)" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9 activity-add " data-id="0" data-bs-toggle="modal" data-bs-target="#modal-dialog-activity-edit">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create") }}
                        </a>
                        <a href="{{ route('assigned-training.result', $parameters) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("app.trainer") }}</th>
                                <th>{{ __("app.type") }}</th>
                                <th>{{ __("app.date") }}</th>
                                <th>{{ __("app.status") }}</th>
                                <th>{{ __("app.duration") }}</th>
                                <th>{{ __("app.notes") }}</th>
                                <th class="table-actions">{{ __("app.actions") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($assigned_training->activities as $activity)
                            @php
                            $action = route('activity.destroy', [$locale, false]);
                            $id = $activity->id;
                            $name = $activity->name;
                            $message_question = __('message.confirmation_delete_item');
                            $message_warning = '';
                            @endphp
                            <tr data-id="{{ $activity->id }}">
                                <td class="table-reference">{{ $activity->id }}</td>
                                <td>{{ $activity->trainer->lname }} {{ $activity->trainer->fname }}</td>
                                <td class="bg-{{ $activity->type == 'Theory' ? 'primary' : 'info' }}">{{ __('app.' . ($activity->type ? : 'none')) }}</td>
                                <td>{{ $activity->date }}</td>
                                <td class="bg-{{ $activity->status == 'Completed' ? 'success' : 'warning' }}">{{ __('app.' . ($activity->status ? : 'none')) }}</td>
                                <td>{{ $activity->duration }}</td>
                                <td>{{ $activity->notes }}</td>
                                <td class="table-actions">
                                    <a href="{{ route('activity.complete', [$locale, $activity->id]) }}" class="text-primary check">
                                        <i class="ti ti-check fs-5 text-success"></i>
                                    </a>
                                    <a href="#" class="text-primary activity-edit" data-id="{{ $activity->id }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-activity-edit">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="javascript:void(0)" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5 text-danger"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                            @if (!count($assigned_training->activities))
                            <tr>
                                <td colspan="8">
                                    {{ __('app.no_results_found') }}
                                </td>
                            </tr>
                            @endif
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Modal dialog -->
<form action="{{ route('activity.store', $locale) }}" method="POST" id="modal-dialog-activity-edit-form" class="needs-validation" novalidate>
    @csrf
    <input type="hidden" id="modal_id" name="id" value="" />
    <input type="hidden" name="presentiel_id" value="" />
    <input type="hidden" name="assigned_training_id" value="{{ $assigned_training->id }}" />
    <div id="modal-dialog-activity-edit" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-activity-edit-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-activity-edit-label">
                        <span id="modal-activity-title">{{ __('app.activity_for') }}</span>
                        <span id="modal-training-name">{{ $assigned_training->training->name }}</span>
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="alert alert-warning text-warning confirmation-create-activity">
                        {{ __('message.confirmation_create_activity_for_result_attestation') }}
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="modal_trainer_id" name="trainer_id" aria-label="{{ __('app.trainer') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($trainers as $trainer)
                                    <option value="{{ $trainer->id }}">
                                        {{ $trainer->fname}} {{ $trainer->lname}} ({{ $trainer->training_institution}}) @if (!$trainer->user_id) [Ext]@endif
                                    </option>
                                    @endforeach
                                </select>
                                <label for="modal_trainer_id">{{ __('app.trainer') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="date" id="modal_date" name="date" class="form-control">
                                <label for="modal_date">{{ __('app.date') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="modal_status" name="status" aria-label="{{ __('app.status') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($activities_status as $key => $val)
                                    <option value="{{ $key }}">{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="modal_status">{{ __('app.status') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="modal_type" name="type" aria-label="{{ __('app.type') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($activities_type as $key => $val)
                                    <option value="{{ $key }}">{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="modal_type">{{ __('app.type') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <input type="text" id="modal_duration" name="duration" class="form-control">
                                <label for="modal_duration">{{ __('app.duration') }} (H:m:s)</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="modal_notes" name="notes" placeholder="{{ __('app.notes') }}" style="height: 115px;"></textarea>
                                <label for="modal_notes">{{ __('app.notes') }}</label>
                            </div>
                        </div>
                    </div>
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-check fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn btn-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Javascript -->
<script type="text/javascript">
    // Dropzone.autoDiscover = false;
    $(function() {
        $(".confirmation-create-activity").hide();
        $("a.activity-edit").click(function() {
            $(".confirmation-create-activity").hide();
            $("#modal-activity-title").html("{{ __('app.activity_for') }}");
            $("#modal_date").attr("disabled", true);
            $("#modal_type").attr("disabled", true);
            $("#modal_id").val("");
            $("#modal_trainer_id").val("");
            $("#modal_date").val("");
            $("#modal_status").val("");
            $("#modal_type").val("");
            $("#modal_duration").val("");
            $("#modal_notes").html("");
            var id = $(this).data("id");
            $.ajax({
                url: '{{ route("activity.get-full", [$locale]) }}',
                type: 'GET',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: id
                },
                dataType: 'json',
                success: function(activity) {
                    if (activity) {
                        $("#modal_id").val(activity.id);
                        $("#modal_trainer_id").val(activity.trainer_id).trigger('change');
                        $("#modal_date").val(activity.date);
                        $("#modal_status").val(activity.status).trigger('change');
                        $("#modal_type").val(activity.type).trigger('change');
                        $("#modal_duration").val(activity.duration);
                        $("#modal_notes").html(activity.notes);
                    }
                }
            });
        });

        $("a.activity-add").click(function() {
            $("#modal-activity-title").html("{{ __('app.create_activity_for') }}");
            <?= $assigned_training->status == 'Completed' ? '$(".confirmation-create-activity").show();' : '' ?>
            $("#modal_date").attr("disabled", false);
            $("#modal_type").attr("disabled", false);
            $("#modal_id").val("");
            $("#modal_trainer_id").val("");
            $("#modal_date").val("");
            $("#modal_status").val("");
            $("#modal_type").val("");
            $("#modal_duration").val("");
            $("#modal_notes").html("");
        });
    });
</script>

@endsection