@extends('layouts.app-bo')
@section('title', __('app.create_new_training_demand'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card" id="training-demand">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="solar:book-bookmark-minimalistic-outline"></iconify-icon>
                            {{ __("app.create_new_training_demand") }}
                        </h4>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training-demand.list', $locale) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <br />
                <form action="{{ route('training-demand.store', $locale) }}" method="POST" enctype="multipart/form-data" onsubmit="return validation()" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ isset($training_demand) ? $training_demand->id : '' }}" />
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="applicant_id" name="applicant_id" aria-label="{{ __('app.applicant_1st_level') }}" disabled>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($users as $user)
                                    <option value="{{ $user->id }}" @if (Auth::user()->id == $user->id) selected @endif>{{ $user->lname }}, {{ $user->fname }}</option>
                                    @endforeach
                                </select>
                                <label for="applicant_id">{{ __('app.applicant_1st_level') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="demand_date" name="demand_date" placeholder="{{ __('app.demand_date') }}" value="{{ date('Y-m-d') }}" disabled />
                                <label for="demand_date">{{ __('app.demand_date') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="start_date" name="start_date" placeholder="{{ __('app.date_of_training') }}" required />
                                <label for="start_date">{{ __('app.date_of_training') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form mb-3">
                                <label for="user_ids">{{ __('users.users') }}</label>
                                <select class="form-select select2" id="user_ids" name="user_ids[]" aria-label="{{ __('users.users') }}" multiple="multiple">
                                    @foreach ($users as $user)
                                    <option value="{{ $user->id }}">{{ $user->lname }}, {{ $user->fname }} [{{ $user->ref }}] @if ($user->nas) [{{ $user->nas }}] @endif</option>
                                    @endforeach
                                </select>
                                <div id="error-user_ids" class="alert alert-danger mt-1" style="display: none;">{{ __('app.field_required') }}</div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="alert alert-primary text-primary">
                                {{ __('message.please_select_training_or_description') }}
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="platform_id" name="platform_id" aria-label="{{ __('app.platform') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($platforms as $platform)
                                    <option value="{{ $platform->id }}">{{ $platform->type }}</option>
                                    @endforeach
                                </select>
                                <label for="platform_id">{{ __('app.platform') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="category_id" name="category_id" aria-label="{{ __('app.training_category') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($categories as $category)
                                    <option value="{{ $category->id }}">{{ $category->new_name }}</option>
                                    @endforeach
                                </select>
                                <label for="category_id">{{ __('app.training_category') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form mb-3" id="div-training_ids">
                                <label for="training_ids">{{ __('app.training_name') }}</label>
                                <select class="form-select select2" id="training_ids" name="training_ids[]" aria-label="{{ __('app.training_name') }}" multiple="multiple">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($trainings as $training)
                                    <option value="{{ $training->id }}">{{ $training->name }} [{{ $training->prefix }}]</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="description" name="description" placeholder="{{ __('app.description') }}" style="height: 80px;">{{ old('description') ? : (isset($training_demand) ? $training_demand->description : '') }}</textarea>
                                <label for="description">{{ __('app.description') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="alert alert-primary text-primary">
                                {{ __('message.please_select_level2_or_level3_user') }}
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form mb-3">
                                <label for="level2">{!! __('app.send_to_2nd_level_approval_optional') !!}</label>
                                <select class="form-select select2" id="level2" name="level2[]" aria-label="{{ __('app.send_to_2nd_level_approval_optional') }}" multiple="multiple">
                                    @foreach ($users_level2 as $user)
                                    <option value="{{ $user->id }}">{{ $user->lname }}, {{ $user->fname }} [{{ $user->ref }}] @if ($user->nas) [{{ $user->nas }}] @endif</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form mb-3">
                                <label for="level3">{!! __('app.skip_2nd_level_and_directly_send_to_3rd_level_approval') !!}</label>
                                <select class="form-select select2" id="level3" name="level3[]" aria-label="{{ __('app.skip_2nd_level_and_directly_send_to_3rd_level_approval') }}" multiple="multiple">
                                    @foreach ($users_level3 as $user)
                                    <option value="{{ $user->id }}">{{ $user->lname }}, {{ $user->fname }} [{{ $user->ref }}] @if ($user->nas) [{{ $user->nas }}] @endif</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="team_id" name="team_id" aria-label="{{ __('app.team') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($teams as $team)
                                    <option value="{{ $team->id }}">{{ $team->name }}</option>
                                    @endforeach
                                </select>
                                <label for="team_id">{{ __('app.team') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="location_id" name="location_id" aria-label="{{ __('app.training_location') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($locations as $location)
                                    <option value="{{ $location->id }}">{{ $location->name }}</option>
                                    @endforeach
                                </select>
                                <label for="location_id">{{ __('app.training_location') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-3">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="decision_made" name="decision_made" aria-label="{{ __('app.2nd_level_decision_status') }}" disabled>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($decision_status as $key => $val)
                                    <option value="{{ $key }}">{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="decision_made">{{ __('app.2nd_level_decision_status') }}</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="decision_date" name="decision_date" placeholder="{{ __('app.2nd_level_decision_date') }}" disabled/>
                                <label for="decision_date">{{ __('app.2nd_level_decision_date') }}</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="status" name="status" aria-label="{{ __('app.3rd_level_decision_status') }}" disabled>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($decision_status as $key => $val)
                                    <option value="{{ $key }}">{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="status">{{ __('app.3rd_level_decision_status') }}</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="completed_date" name="completed_date" placeholder="{{ __('app.3rd_level_decision_date') }}" disabled/>
                                <label for="completed_date">{{ __('app.3rd_level_decision_date') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="form-actions">
                        <div class="card-body text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    $(document).ready(function() {
        add_select_all('user_ids');
        add_select_all('level2');
        add_select_all('level3');
        add_select_all('training_ids');
        $("#platform_id, #category_id").change(function() {
            set_training_list();
        });
    });

    function validation() {
        var user_ids = $('#user_ids').val();
        var valid = true;
        if (user_ids.length) {
            $('#error-user_ids').hide();
        } else {
            $('#error-user_ids').show();
            valid = false;
        }
        return valid;
    }

    function set_training_list() {
        $.ajax({
            url: '{{ route("training-demand.training-list", [$locale]) }}',
            type: 'GET',
            data: {
                _token: '{{ csrf_token() }}',
                platform_id: $('#platform_id').val(),
                category_id: $('#category_id').val()
            },
            dataType: 'html',
            success: function(response) {
                $("#div-training_ids").html(response);
                $("#training_ids.select2").select2().change();
                $("#select2-training_ids-container").css("padding", "0.625rem 1rem").css("height", "58px");
                add_select_all('training_ids');
            }
        });
    }

    function add_select_all(id) {
        $('#' + id).select2({
            placeholder: "{{ __('app.select') }} ...",
            allowClear: true
        });

        const selectAllOption = new Option("{{ __('app.select_all') }}", 'select_all');
        $('#' + id).prepend(selectAllOption).trigger('change');

        $('#' + id).on('select2:select', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option:not([value="select_all"])').prop('selected', true).trigger('change');
            }
        });

        $('#' + id).on('select2:unselect', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option').prop('selected', false).trigger('change');
            }
        });
    }
</script>
@endsection