@extends('layouts.app-bo')
@section('title', !isset($training) ? __("app.create_training") : (__('app.update_training') . ' : ' . $training->name))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            @if (isset($training))
                            {{ __("app.update_training") }} : {{ $training->name }}
                            @else
                            {{ __("app.create_training") }}
                            @endif
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.category') }} : </b> {{ __('menus.' . $category->code) }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training.index', [$locale]) . '#' . $category->code }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <form action="{{ route('training.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ isset($training) ? $training->id : '' }}" />
                    <input type="hidden" name="company_id" value="{{ $company->id }}" />
                    <input type="hidden" name="category_id" value="{{ $category->id }}" />
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="id" value="{{ isset($training) ? $training->id : '' }}" placeholder="{{ __('app.training_id') }}" disabled />
                                <label for="id">{{ __('app.training_id') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select @error('platform_id') is-invalid @enderror" id="platform_id" name="platform_id" aria-label="{{ __('app.platform') }}" required>
                                    <option></option>
                                    @foreach ($platforms as $platform)
                                    <option value="{{ $platform->id }}" {{ old('platform_id') == $platform->id ? 'selected' : (isset($training) && $training->platform_id == $platform->id ? 'selected' : '') }}>{{ $platform->type }}</option>
                                    @endforeach
                                </select>
                                <label for="platform_id">{{ __('app.platform') }}</label>
                                @error('platform_id')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control @error('name') is-invalid @enderror" id="name" name="name" value="{{ old('name') ? : (isset($training) ? $training->name : '') }}" placeholder="{{ __('app.name') }}" required />
                                <label for="name">{{ __('app.name') }}</label>
                                @error('name')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control @error('name') is-invalid @enderror" id="prefix" name="prefix" value="{{ old('prefix') ? : (isset($training) ? $training->prefix : '') }}" placeholder="{{ __('app.prefix') }}" required />
                                <label for="prefix">{{ __('app.prefix') }}</label>
                                @error('prefix')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="number" class="form-control" id="max_attendancy" name="max_attendancy" value="{{ old('max_attendancy') ? : (isset($training) ? $training->max_attendancy : '') }}" placeholder="{{ __('app.max_attendancy') }}" disabled />
                                <label for="max_attendancy">{{ __('app.max_attendancy') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="number" step="any" class="form-control" id="cost" name="cost" value="{{ old('cost') ? : (isset($training) ? $training->cost : '') }}" placeholder="{{ __('app.cost') }}" />
                                <label for="cost">{{ __('app.cost') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="number" class="form-control" id="refresh" name="refresh" value="{{ old('refresh') ? : (isset($training) ? $training->refresh : '') }}" placeholder="{{ __('app.refresh_after_years') }}" />
                                <label for="refresh">{{ __('app.refresh_after_years') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select @error('platform_id') is-invalid @enderror" id="result" name="result" aria-label="{{ __('app.select_result_of_training_competion') }}" required>
                                    <option></option>
                                    @foreach ($training_result as $tresult)
                                    <option value="{{ $tresult->id }}" {{ old('result') == $tresult->id ? 'selected' : (isset($training) && $training->result == $tresult->id ? 'selected' : '') }}>{{ $tresult->name }}</option>
                                    @endforeach
                                </select>
                                <label for="result">{{ __('app.select_result_of_training_competion') }}</label>
                                @error('result')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="number" class="form-control" id="threshold" name="threshold" value="{{ old('threshold') ? : (isset($training) ? $training->threshold : '') }}" placeholder="{{ __('app.exam_threshold') }}" />
                                <label for="threshold">{{ __('app.exam_threshold') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="requires_theory" name="requires_theory" aria-label="{{ __('app.requires_theory') }}">
                                    <option></option>
                                    @foreach ($yes_or_no_lists as $yes_or_no)
                                    <option value="{{ $yes_or_no->id }}" {{ old('requires_theory') === $yes_or_no->id ? 'selected' : (isset($training) && $training->requires_theory === $yes_or_no->id ? 'selected' : '') }}>{{ __("app.$yes_or_no->name") }}</option>
                                    @endforeach
                                </select>
                                <label for="requires_theory">{{ __('app.requires_theory') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="requires_practice" name="requires_practice" aria-label="{{ __('app.requires_practice') }}">
                                    <option></option>
                                    @foreach ($yes_or_no_lists as $yes_or_no)
                                    <option value="{{ $yes_or_no->id }}" {{ old('requires_practice') === $yes_or_no->id ? 'selected' : (isset($training) && $training->requires_theory === $yes_or_no->id ? 'selected' : '') }}>{{ __("app.$yes_or_no->name") }}</option>
                                    @endforeach
                                </select>
                                <label for="requires_practice">{{ __('app.requires_practice') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="number" class="form-control" id="duration_th" name="duration_th" value="{{ old('duration_th') ? : (isset($training) ? $training->duration_th : '') }}" placeholder="{{ __('app.enter_duration_th') }}" disabled />
                                <label for="duration_th">{{ __('app.duration_th') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="number" class="form-control" id="duration_pr" name="duration_pr" value="{{ old('duration_pr') ? : (isset($training) ? $training->duration_pr : '') }}" placeholder="{{ __('app.enter_duration_pr') }}" disabled />
                                <label for="duration_pr">{{ __('app.duration_pr') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="needs_exam_th" name="needs_exam_th" aria-label="{{ __('app.needs_exam_th') }}" disabled>
                                    <option></option>
                                    @foreach ($yes_or_no_lists as $yes_or_no)
                                    <option value="{{ $yes_or_no->id }}" {{ old('needs_exam_th') === $yes_or_no->id ? 'selected' : (isset($training) && $training->needs_exam_th === $yes_or_no->id ? 'selected' : '') }}>{{ __("app.$yes_or_no->name") }}</option>
                                    @endforeach
                                </select>
                                <label for="needs_exam_th">{{ __('app.needs_exam_th') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="needs_exam_pr" name="needs_exam_pr" aria-label="{{ __('app.needs_exam_pr') }}" disabled>
                                    <option></option>
                                    @foreach ($yes_or_no_lists as $yes_or_no)
                                    <option value="{{ $yes_or_no->id }}" {{ old('needs_exam_pr') === $yes_or_no->id ? 'selected' : (isset($training) && $training->needs_exam_pr === $yes_or_no->id ? 'selected' : '') }}>{{ __("app.$yes_or_no->name") }}</option>
                                    @endforeach
                                </select>
                                <label for="needs_exam_pr">{{ __('app.needs_exam_pr') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="training_level_id" name="training_level_id" aria-label="{{ __('app.level_of_the_training') }}">
                                    <option></option>
                                    @foreach ($training_levels as $training_level)
                                    <option value="{{ $training_level->id }}" {{ old('training_level_id') == $training_level->id ? 'selected' : (isset($training) && $training->training_level_id == $training_level->id ? 'selected' : '') }}>{{ $training_level->name }}</option>
                                    @endforeach
                                </select>
                                <label for="training_level_id">{{ __('app.level_of_the_training') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="task_video_restrict_fstforward" name="task_video_restrict_fstforward" aria-label="{{ __('app.task_video_restrict_fstforward') }}">
                                    <option></option>
                                    @foreach ($yes_or_no_lists as $yes_or_no)
                                    <option value="{{ $yes_or_no->id }}" {{ old('task_video_restrict_fstforward') === $yes_or_no->id ? 'selected' : (isset($training) && $training->task_video_restrict_fstforward === $yes_or_no->id ? 'selected' : '') }}>{{ __("app.$yes_or_no->name") }}</option>
                                    @endforeach
                                </select>
                                <label for="task_video_restrict_fstforward">{{ __('app.task_video_restrict_fstforward') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-check mb-3">
                                <input type="checkbox" class="form-check-input" id="randomize" name="randomize" value="1" placeholder="{{ __('app.randomize_exam_question_order') }}" {{ old('randomize') ? 'checked' : (isset($training) && $training->randomize ? 'checked' : '') }}>
                                <label class="form-check-label" for="randomize">{{ __('app.randomize_exam_question_order') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-check mb-3">
                                <input type="checkbox" class="form-check-input" id="disable" name="disable" value="1" placeholder="{{ __('app.disable_training_after_completion') }}" {{ old('disable') ? 'checked' : (isset($training) && $training->disable ? 'checked' : '') }}>
                                <label class="form-check-label" for="disable">{{ __('app.disable_training_after_completion') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-check mb-3">
                                <input type="checkbox" class="form-check-input" id="self_assign" name="self_assign" value="1" placeholder="{{ __('app.can_be_self_assigned') }}" {{ old('self_assign') ? 'checked' : (isset($training) && $training->self_assign ? 'checked' : '') }}>
                                <label class="form-check-label" for="self_assign">{{ __('app.can_be_self_assigned') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">

                        </div>
                        <div class="col-md-4">
                            <div class="form-check mb-3">
                                <input type="checkbox" class="form-check-input" id="paid" name="paid" value="1" placeholder="{{ __('app.paid_training') }}" {{ old('paid') ? 'checked' : (isset($training) && $training->paid ? 'checked' : '') }}>
                                <label class="form-check-label" for="paid">{{ __('app.paid_training') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-check mb-3">
                                <input type="checkbox" class="form-check-input" id="contractor_assign" name="contractor_assign" value="1" placeholder="{{ __('app.can_be_assigned_by_a_contractor') }}" {{ old('contractor_assign') ? 'checked' : (isset($training) && $training->contractor_assign ? 'checked' : '') }}>
                                <label class="form-check-label" for="contractor_assign">{{ __('app.can_be_assigned_by_a_contractor') }}</label>
                            </div>
                        </div>
                    </div>
                    <hr>
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="department_id" name="department_id" aria-label="{{ __('app.department') }}">
                                    <option></option>
                                    @foreach ($departments as $department)
                                    <option value="{{ $department->id }}" {{ old('department_id') == $department->id ? 'selected' : (isset($training) && $training->department_id == $department->id ? 'selected' : '') }}>{{ $department->name }}</option>
                                    @endforeach
                                </select>
                                <label for="department_id">{{ __('app.department') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="subdepartment_id" name="subdepartment_id" aria-label="{{ __('app.subdepartment') }}">
                                    <option></option>
                                    @foreach ($subdepartments as $subdepartment)
                                    <option value="{{ $subdepartment->id }}" {{ old('subdepartment_id') == $subdepartment->id ? 'selected' : (isset($training) && $training->subdepartment_id == $subdepartment->id ? 'selected' : '') }}>{{ $subdepartment->name }}</option>
                                    @endforeach
                                </select>
                                <label for="subdepartment_id">{{ __('app.subdepartment') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="location_id" name="location_id" aria-label="{{ __('app.location_division') }}">
                                    <option></option>
                                    @foreach ($locations as $location)
                                    <option value="{{ $location->id }}" {{ old('location_id') == $location->id ? 'selected' : (isset($training) && $training->location_id == $location->id ? 'selected' : '') }}>{{ $location->name }}</option>
                                    @endforeach
                                </select>
                                <label for="location_id">{{ __('app.location_division') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="equipement_id" name="equipement_id" aria-label="{{ __('app.equipement') }}">
                                    <option></option>
                                    @foreach ($equipements as $equipement)
                                    <option value="{{ $equipement->id }}" {{ old('equipement_id') == $equipement->id ? 'selected' : (isset($training) && $training->equipement_id == $equipement->id ? 'selected' : '') }}>{{ $equipement->name }}</option>
                                    @endforeach
                                </select>
                                <label for="equipement_id">{{ __('app.equipement') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="form_id" name="form_id" aria-label="{{ __('app.form') }}">
                                    <option></option>
                                    @foreach ($forms as $form)
                                    <option value="{{ $form->id }}" {{ old('form_id') == $form->id ? 'selected' : (isset($training) && $training->form_id == $form->id ? 'selected' : '') }}>{{ $form->name }}</option>
                                    @endforeach
                                </select>
                                <label for="form">{{ __('app.form') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="survey_id" name="survey_id" aria-label="{{ __('app.personal_survey') }}" disabled>
                                    <option></option>
                                    @foreach ($surveys as $survey)
                                    <option value="{{ $survey->id }}" {{ old('survey_id') == $survey->id ? 'selected' : (isset($training) && $training->survey_id == $survey->id ? 'selected' : '') }}>{{ $survey->name }}</option>
                                    @endforeach
                                </select>
                                <label for="survey_id">{{ __('app.personal_survey') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="details" name="details" placeholder="{{ __('app.details') }}" style="height: 115px;">{{ old('details') ? : (isset($training) ? $training->details : '') }}</textarea>
                                <label for="details">{{ __('app.details') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="signer_id" name="signer_id" aria-label="{{ __('app.signer') }}">
                                    <option></option>
                                    @foreach ($signers as $signer)
                                    <option value="{{ $signer->id }}" {{ old('signer_id') == $signer->id ? 'selected' : (isset($training) && $training->signer_id == $signer->id ? 'selected' : '') }}>{{ $signer->name }}</option>
                                    @endforeach
                                </select>
                                <label for="signer_id">{{ __('app.signer') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            @if (isset($training))
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="rev" name="rev" value="{{ old('rev') ? : (isset($training) ? $training->rev : '') }}" placeholder="{{ __('app.revision') }}" />
                                <label for="rev">{{ __('app.revision') }}</label>
                            </div>
                            @endif
                        </div>
                    </div>
                    @if (isset($training))
                    <div class="row">
                        <div class="col-md-12 text-center">
                            <div class="form-check mb-3">
                                <label class="form-check-label" for="notification">{{ __('app.send_notification_to_assigned_trainees_about_revision_change') }}
                                    <input type="checkbox" class="form-check-input" id="notification" name="notification" value="1" placeholder="{{ __('app.send_notification_to_assigned_trainees_about_revision_change') }}" {{ old('notification') ? 'checked' : '' }}>
                                </label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="rev" name="rev" value="{{ old('rev') ? : (isset($training) ? $training->rev : '') }}" placeholder="{{ __('app.revision') }}" />
                                <label for="rev">{{ __('app.revision') }}</label>
                            </div>
                        </div>
                    </div>
                    @endif
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form mb-3">
                                <label class="form-label" for="dropzone-image">{{ __('app.upload_image') }}</label>
                                <div class="dropzone" id="dropzone-image">
                                    <div class="dz-button" type="button">{{ __('app.drag_drop_files_here') }}</div>
                                </div>
                                <br />
                                <input class="form-control" type="file" id="image" name="image" id="image" accept="image/*" placeholder="{{ __('app.select_file') }}">
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form mb-3">
                                <label class="form-label" for="dropzone-documents">{{ __('app.upload_documents') }}</label>
                                <div class="dropzone" id="dropzone-documents">
                                    <div class="dz-button" type="button">{{ __('app.drag_drop_files_here') }}</div>
                                </div>
                                <br />
                                <input class="form-control" id="documents" name="documents[]" type="file" placeholder="{{ __('app.select_files') }}" multiple />
                            </div>
                        </div>
                    </div>
                    <br />
                    <div class="form-actions">
                        <div class="card-body border-top text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                            <a href="{{ route('training.index', [$locale]) . '#' . $category->code }}" class="btn bg-danger-subtle text-danger ms-6">
                                <i class="ti ti-circle-x fs-4"></i>
                                {{ __('app.cancel') }}
                            </a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    // Dropzone.autoDiscover = false;
    $(function() {
        $("#platform_id").change(function() {
            var platform_id = $(this).val();
            if (platform_id == 2) {
                $("#max_attendancy").removeAttr("disabled");
                $("#requires_theory").removeAttr("disabled");
                $("#requires_practice").removeAttr("disabled");
            } else {
                $("#max_attendancy").attr("disabled", true);
                $("#requires_theory").attr("disabled", true);
                $("#requires_practice").attr("disabled", true);
            }
        }).change();

        $("#requires_theory").change(function() {
            var requires_theory = $(this).val();
            if (requires_theory == 1) {
                $("#duration_th").removeAttr("disabled");
                $("#needs_exam_th").removeAttr("disabled");
            } else {
                $("#duration_th").attr("disabled", true);
                $("#needs_exam_th").attr("disabled", true);
            }
        }).change();

        $("#requires_practice").change(function() {
            var requires_practice = $(this).val();
            if (requires_practice == 1) {
                $("#duration_pr").removeAttr("disabled");
                $("#needs_exam_pr").removeAttr("disabled");
            } else {
                $("#duration_pr").attr("disabled", true);
                $("#needs_exam_pr").attr("disabled", true);
            }
        }).change();
    });
</script>

@endsection