@extends('layouts.app-bo')
@section('title', !isset($form) ? __("app.create_form") : (__('app.update_form') . ' : ' . $form->name))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <form action="{{ route('form.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
            @csrf
            <input type="hidden" name="id" value="{{ isset($form) ? $form->id : '' }}" />
            <input type="hidden" name="company_id" value="{{ $company->id }}" />
            <input type="hidden" name="category_id" value="{{ $category->id }}" />
            <div class="card">
                <div class="card-body">
                    <div class="d-md-flex align-items-center justify-content-between">
                        <div class="mb-4 mb-md-0">
                            <h4 class="card-title">
                                @if (isset($form))
                                {{ __("app.update_form") }} : {{ $form->name }}
                                @else
                                {{ __("app.create_form") }}
                                @endif
                            </h4>
                            <div class="mb-3 card-subtitle"><b>{{ __('app.category') }} : </b> {{ __('menus.' . $category->code) }}</div>
                        </div>
                        <div class="d-flex align-items-center justify-content-between gap-6">
                            <a href="{{ route('training.index', [$locale]) . '#' . $category->code }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                                <i class="ti ti-arrow-back-up fs-4"></i>
                                {{ __("app.back") }}
                            </a>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control @error('name') is-invalid @enderror" id="name" name="name" value="{{ old('name') ? : (isset($form) ? $form->name : '') }}" placeholder="{{ __('app.name') }}" required />
                                <label for="name">{{ __('app.name') }}</label>
                                @error('name')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-check mb-3">
                                <input type="checkbox" class="form-check-input" id="presentiel" name="presentiel" value="1" placeholder="{{ __('app.is_this_a_presentiel_training_form') }} ?" {{ old('presentiel') ? 'checked' : (isset($form) && $form->presentiel ? 'checked' : '') }}>
                                <label class="form-check-label" for="presentiel">{{ __('app.is_this_a_presentiel_training_form') }} ?</label>
                            </div>
                        </div>
                    </div>
                    <div class="row div_training_id">
                        <div class="col-md-12">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="training_id" name="training_id" aria-label="{{ __('app.training') }}">
                                    <option>{{ __('app.select') }} ...</option>
                                    @foreach ($trainings as $training)
                                    <option value="{{ $training->id }}" {{ old('training_id') ? 'selected' : (isset($form) && $training->id == $form->training_id ? 'selected' : '') }}>[{{ $training->prefix }}] {{ $training->name }}</option>
                                    @endforeach
                                </select>
                                <label for="training_id">{{ __('app.training') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="form-actions">
                        <div class="card-body border-top text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                            <a href="{{ route('training.index', [$locale]) . '#' . $category->code }}" class="btn bg-danger-subtle text-danger ms-6">
                                <i class="ti ti-circle-x fs-4"></i>
                                {{ __('app.cancel') }}
                            </a>
                        </div>
                    </div>
                    @if ($has_assign_to_user)
                    <div class="text-center">
                        <span class="mb-3 badge bg-primary-subtle text-primary text-wrap" style="padding: 20px;width: 100%;text-align: left;--bs-badge-color: #000;">
                            {{ __('app.assign_to_user_text_warning') }}
                        </span>
                    </div>
                    @endif
                </div>
            </div>
            @if (isset($form))
            <div class="card">
                <div class="card-body">
                    <div class="d-md-flex align-items-center justify-content-between">
                        <div class="mb-4 mb-md-0">
                            <h4 class="card-title">
                                {{ __('app.form_fields') }}
                            </h4>
                            <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($form_fields) }}</b> {{ __('app.items') }}</div>
                        </div>
                        <div class="d-flex align-items-center justify-content-between gap-6">
                            <a href="{{ route('form-field.create', [$locale, $form->id]) }}" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9" id="create-form-field">
                                <i class="ti ti-plus fs-4"></i>
                                {{ __("app.add_new") }}
                            </a>
                        </div>
                    </div>
                    <div class="{{ $setting->table_div_class }}">
                        <table class="{{ $setting->table_class }}" id="form-field-list">
                            <thead class="{{ $setting->table_thead_class }}">
                                <tr>
                                    <th class="table-reference">{{ __("app.order") }}</th>
                                    <th>{{ __("app.field") }}</th>
                                    <th>{{ __("app.type") }}</th>
                                    <th>{{ __("app.required") }}</th>
                                    <th class="table-actions">{{ __("app.actions") }}</th>
                                </tr>
                            </thead>
                            <tbody class="{{ $setting->table_tbody_class }}">
                                @foreach ($form_fields as $form_field)
                                @php
                                $action = route('form-field.destroy', [$locale, $form->id]);
                                $id = $form_field->id;
                                $name = $form_field->field;
                                $message_question = __('message.confirmation_delete_item');
                                $message_warning = "";
                                @endphp
                                <tr data-id="{{ $form_field->id }}" class="line">
                                    <td class="table-reference drag-handle" style="cursor: move;"><i class="ti ti-arrows-up-down fs-5"></i></td>
                                    <td>{{ $form_field->field }}</td>
                                    <td>{{ __('app.' . $form_field_types[$form_field->type]) }}</td>
                                    <td>
                                        @if ($form_field->required == 1)
                                        <i class="ti ti-square-rounded-check fs-5 text-success"></i>
                                        @elseif ($form_field->required == 0)
                                        <i class="ti ti-square-rounded-x fs-5 text-danger"></i>
                                        @else
                                        <i class="ti ti-square-rounded fs-5 text-muted"></i>
                                        @endif
                                    </td>
                                    <td class="table-actions">
                                        <a href="{{ route('form-field.edit', [$locale, $form->id, $form_field->id]) }}" class="text-primary edit form-form-field-edit" data-id="{{ $form_field->id }}">
                                            <i class="ti ti-edit fs-5"></i>
                                        </a>
                                        <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                            <i class="ti ti-trash fs-5"></i>
                                        </a>
                                    </td>
                                </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
            @endif
        </form>
    </section>
</div>

<script type="text/javascript">
    // Dropzone.autoDiscover = false;
    $(function() {
        $("#presentiel").change(function() {
            if ($(this).is(":checked")) {
                $("div.div_training_id").show();
            } else {
                $("div.div_training_id").hide();
            }
        }).change();

        $("table#form-field-list tbody").sortable({
            handle: ".drag-handle",
            items: "tr.line",
            cursor: "move",
            placeholder: "ui-state-highlight",
            start: function(e, ui) {
                ui.placeholder.height(ui.item.height());
            },
            update: function(event, ui) {
                var elements = $(this).sortable('toArray', {
                    attribute: 'data-id'
                });
                $.ajax({
                    url: '{{ route("form-field.update.order", [$locale]) }}',
                    type: 'POST',
                    data: {
                        _token: '{{ csrf_token() }}',
                        form_id: '{{ isset($form) ? $form->id : 0 }}',
                        ids: elements
                    },
                    dataType: 'json',
                    success: function() {
                        toastr.success(
                            "success",
                            "{{ __('message.order_updated') }}", {
                                showMethod: "fadeIn",
                                hideMethod: "fadeOut",
                                timeOut: 1000,
                                closeButton: true
                            }
                        );
                    }
                });
            }
        });
        $("#table#module-task-list tbody").disableSelection();
    });
</script>

@endsection