@extends('layouts.app-bo')
@section('title', __('app.training_groups'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="solar:book-bookmark-minimalistic-outline"></iconify-icon>
                            {{ __("app.training_groups") }}
                        </h4>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="#" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit" id="dialog-create">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create") }}
                        </a>
                        <a href="#" class="btn btn-primary d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit" id="dialog-create-existing">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create_from_existing") }}
                        </a>
                    </div>
                </div>
                <div class="mt-3">
                    @if ($training_groups->total() <= $training_groups->perPage())
                    <p>{{ __('pagination.Showing') }} {{ $training_groups->total() }} {{ __('pagination.results') }}</p>
                    @else
                    {{ $training_groups->appends(request()->query())->links() }}
                    @endif
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("app.prefix") }}</th>
                                <th>{{ __("app.title") }}</th>
                                <th>{{ __("app.description") }}</th>
                                <th>{{ __("app.trainings") }}</th>
                                <th class="table-actions sticky-search-button">{{ __("app.actions") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($training_groups as $training_group)
                            @php
                            $action = route('training-group.destroy', [$locale]);
                            $id = $training_group->id;
                            $name = $training_group->name;
                            $message_question = __('message.confirmation_delete_item');
                            $message_warning = '';
                            @endphp
                            <tr>
                                <td class="table-reference">{{ $training_group->id }}</td>
                                <td>{{ $training_group->prefix }}</td>
                                <td>{{ $training_group->name }}</td>
                                <td>{{ $training_group->description }}</td>
                                <td nowrap>
                                    @foreach ($categories as $category)
                                    <p><b>{{ __('menus.' . $category->code) }}</b></p>
                                    @if ($training_group->trainings)
                                    <ul>
                                        @foreach ($training_group->trainings as $training)
                                        @if ($training->category->id == $category->id && $training->platform_id == 1)
                                        <li>
                                            <i class="ti ti-box fs-4 me-2"></i>
                                            {{ $training->prefix }} {{ ' Rev.' . $training->rev }} {{ $training->name }}
                                        </li>
                                        @endif
                                        @endforeach
                                    </ul>
                                    @endif
                                    @endforeach
                                    <p><b>{{ __('app.external_presentiel') }}</b></p>
                                    @if ($training_group->trainings)
                                    <ul>
                                        @foreach ($training_group->trainings as $training)
                                        @if ($training->category->id == 1 && $training->platform_id == 2)
                                        <li>
                                            <i class="ti ti-box fs-4 me-2"></i>
                                            {{ $training->prefix }} {{ ' Rev.' . $training->rev }} {{ $training->name }}
                                        </li>
                                        @endif
                                        @endforeach
                                    </ul>
                                    @endif
                                </td>
                                <td class="table-actions sticky-search-button">
                                    <a href="{{ route('training-group.view', [$locale, $training_group->id]) }}" class="text-primary edit form-edit-edit">
                                        <i class="ti ti-eye fs-5"></i>
                                    </a>
                                    <a href="#" class="text-primary edit form-edit" data-id="{{ $training_group->id }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Modal dialog -->
<form action="{{ route('training-group.store', $locale) }}" method="POST" id="modal-dialog-edit-form" class="needs-validation" novalidate>
    @csrf
    <input type="hidden" name="id" id="id" value="" />
    <div id="modal-dialog-edit" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-edit-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-edit-label">
                        {{ __('message.create_training_group') }}
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="name" name="name" value="" placeholder="{{ __('app.title') }}" required />
                                <label for="name">{{ __('app.name') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="prefix" name="prefix" value="" placeholder="{{ __('app.prefix') }}" />
                                <label for="prefix">{{ __('app.prefix') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="description" name="description" value="" placeholder="{{ __('app.description') }}" />
                                <label for="description">{{ __('app.description') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row training_group_id">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" name="training_group_id" id="training_group_id">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($training_groups_existings as $training_group_existing)
                                    <option value="{{ $training_group_existing->id }}">{{ $training_group_existing->name }} [{{ $training_group_existing->prefix }}]</option>
                                    @endforeach
                                </select>
                                <label for="training_group_id">{{ __('app.existing_group') }}</label>
                            </div>
                        </div>
                    </div>
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-circle-x fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn bg-primary-subtle text-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Javascript -->
<script type="text/javascript">
    $(function() {
        $("a#dialog-create").click(function() {
            reset_form(false);
        });

        $("a#dialog-create-existing").click(function() {
            reset_form(true);
        });

        $("a.form-edit").click(function() {
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.update_training_group') }}");
            $("#modal-dialog-edit-form #id").val("");
            $("#modal-dialog-edit-form #prefix").val("");
            $("#modal-dialog-edit-form #name").val("");
            $("#modal-dialog-edit-form #description").val("");
            $("#modal-dialog-edit-form #training_group_id").val("");
            $("div.training_group_id").hide();
            $("select#training_group_id").removeAttr("required");
            var id = $(this).data("id");
            $.ajax({
                url: '{{ route("training-group.get", [$locale]) }}',
                type: 'GET',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: id,
                    model: 'TrainingGroup'
                },
                dataType: 'json',
                success: function(training_group) {
                    if (training_group) {
                        $("#modal-dialog-edit-form #id").val(training_group.id);
                        $("#modal-dialog-edit-form #prefix").val(training_group.prefix);
                        $("#modal-dialog-edit-form #name").val(training_group.name);
                        $("#modal-dialog-edit-form #description").val(training_group.description);
                    }
                }
            });
        });
    });

    function reset_form(existing) {
        $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.create_training_group') }}");
        $("#modal-dialog-edit-form #id").val("");
        $("#modal-dialog-edit-form #prefix").val("");
        $("#modal-dialog-edit-form #name").val("");
        $("#modal-dialog-edit-form #description").val("");
        $("#modal-dialog-edit-form #training_group_id").val("");
        $("div.training_group_id").hide();
        $("select#training_group_id").removeAttr("required");
        if (existing) {
            $("div.training_group_id").show();
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.create_training_group_from_existing') }}");
            $("select#training_group_id").attr("required", true);
        }
    }
</script>
@endsection