@extends('layouts.app-bo')
@section('title', !isset($task) ? __("app.create_new_task") : (__('app.update_tasks') . ' : ' . $task->title))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            @if (isset($task))
                            {{ __("app.update_tasks") }} : {{ $task->title }}
                            @else
                            {{ __("app.create_new_task") }}
                            @endif
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.module') }} : </b> {{ $module->name }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <form action="{{ route('task.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ isset($task) ? $task->id : '' }}" />
                    <input type="hidden" name="module_id" value="{{ $module->id }}" />
                    <input type="hidden" name="training_id" value="{{ $training->id }}" />
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="title" name="title" value="{{ old('title') ? : '' }}" placeholder="{{ __('app.title') }}" required />
                                <label for="title">{{ __('app.title') }}</label>
                                @error('title')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                    </div>
                    @php
                    $data_type_checked_media = old('data_type') == 'media' ? 'checked' : '';
                    $data_type_checked_url = old('data_type') == 'url' ? 'checked' : '';
                    $data_type_checked_scorm = old('data_type') == 'scorm' ? 'checked' : '';
                    @endphp
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-label">
                                <label>{{ __('app.select_the_content_type_of_the_task')}} : </label>
                            </div>
                            <div class="form-check form-check-inline">
                                <input class="form-check-input data_type" type="radio" name="data_type" id="data_type_media" value="media" {{ $data_type_checked_media }} required>
                                <label class="form-check-label" for="data_type_media">{{ __('app.media_question') }}</label>
                            </div>
                            <div class="form-check form-check-inline">
                                <input class="form-check-input data_type" type="radio" name="data_type" id="data_type_url" value="url" {{ $data_type_checked_url }} required>
                                <label class="form-check-label" for="data_type_url">{{ __('app.url') }}</label>
                            </div>
                            @if ($training->category->id != 2)
                            <div class="form-check form-check-inline">
                                <input class="form-check-input data_type" type="radio" name="data_type" id="data_type_scorm" value="scorm" {{ $data_type_checked_scorm }} required>
                                <label class="form-check-label" for="data_type_scorm">{{ __('app.scorm') }}</label>
                            </div>
                            @endif
                            @error('data_type')<div class="alert alert-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    @if ($training->category->id != 2)
                    <div class="row div_scorm_quiz_2004_version div_task">
                        <div class="col-md-12">
                            <br />
                            <span class="mb-1 badge  bg-success-subtle text-success" style="padding: 20px;width: 100%;text-align: left;">
                                {{ __('app.scorm_quiz_2004_version') }}
                            </span>
                            <br /><br />
                        </div>
                    </div>
                    <div class="row div_scorm_version div_task">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="scorm_version" name="scorm_version" aria-label="{{ __('app.scorm_version') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    <option value="1">1.x</option>
                                    <option value="2004">2004</option>
                                </select>
                                <label for="scorm_version">{{ __('app.scorm_version')}}</label>
                            </div>
                        </div>
                    </div>
                    @endif
                    <div class="row div_data_path div_task">
                        <div class="col-md-12 mt-3">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="data_path" name="data_path" value="{{ isset($task) ? $task->data_path : '' }}" placeholder="{{ __('app.enter_external_url') }}" />
                                <label for="data_path">{{ __('app.enter_external_url') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row div_upload div_task">
                        <div class="col-md-12">
                            <br />
                            <div class="form">
                                <label class="form-label" for="upload">{{ __('app.upload') }}</label>
                                <input class="form-control" type="file" id="upload" name="upload" placeholder="{{ __('app.upload') }}">
                                @error('upload')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                    </div>
                    @if ($training->category->id != 2)
                    <div class="row div_upload_scorm_package_zip_file div_task">
                        <div class="col-md-12 mt-3">
                            <span class="mb-1 badge  bg-info-subtle text-info" style="padding: 20px;width: 100%;text-align: left;">
                                {{ __('app.upload_scorm_package_zip_file') }}
                            </span>
                        </div>
                    </div>
                    <div class="row div_question div_task">
                        <div class="col-md-12">
                            <div class="form-check mt-3">
                                <input class="form-check-input" type="checkbox" id="question"" name=" question" value="yes">
                                <label class="form-check-label" for="question">
                                    {{ __('app.add_question') }}
                                </label>
                            </div>
                        </div>
                    </div>
                    <div class="row div_documents div_task">
                        <div class="col-md-12 mt-3">
                            <div class="form-label">
                                <label>{{ __('app.link_training_documents')}} : </label>
                            </div>
                            <div class="form-floating mb-3">
                                <select class="form-select select2" id="documents" name="documents[]" aria-label="{{ __('app.link_training_documents') }}" multiple>
                                    @foreach ($training_documents as $key_doc => $val_doc)
                                    <option value="{{ $key_doc }}">{{ $key_doc }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row div_extra_link div_task">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="extra_link" name="extra_link" value="{{ isset($task) ? $task->extra_link : '' }}" placeholder="{{ __('app.additional_information_url') }}" />
                                <label for="extra_link">{{ __('app.additional_information_url') }}</label>
                            </div>
                        </div>
                    </div>
                    @endif
                    <div class="form-actions">
                        <div class="card-body border-top text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                            <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-danger ms-6">
                                <i class="ti ti-circle-x fs-4"></i>
                                {{ __('app.cancel') }}
                            </a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    // Dropzone.autoDiscover = false;
    $(function() {
        $("input[type='radio'].data_type").change(function() {
            var data_type = $(this).is(":checked") ? $(this).val() : "";
            change_data_type(data_type);
        }).change();

        var data_type = $("input[type='radio'].data_type:checked").val();
        change_data_type(data_type);
    });

    function change_data_type(data_type) {
        var div_task = $("div.div_task");
        var div_scorm_quiz_2004_version = $("div.div_scorm_quiz_2004_version");
        var div_scorm_version = $("div.div_scorm_version");
        var div_data_path = $("div.div_data_path");
        var div_upload = $("div.div_upload");
        var div_upload_scorm_package_zip_file = $("div.div_upload_scorm_package_zip_file");
        var div_question = $("div.div_question");
        var div_documents = $("div.div_documents");
        var div_extra_link = $("div.div_extra_link");
        div_task.hide();
        switch (data_type) {
            case "media":
                div_upload.show();
                div_question.show();
                div_documents.show();
                div_extra_link.show();
                break;
            case "url":
                div_data_path.show();
                div_documents.show();
                div_extra_link.show();
                break;
            case "scorm":
                div_scorm_quiz_2004_version.show();
                div_scorm_version.show();
                div_upload.show();
                div_upload_scorm_package_zip_file.show();
                div_question.show();
                div_documents.show();
                div_extra_link.show();
                break;
            default:
                div_documents.show();
                div_extra_link.show();
                break;
        }
    }
</script>

@endsection