@extends('layouts.app-bo')
@section('title', !isset($task) ? __("app.create_new_task") : (__('app.update_tasks') . ' : ' . $task->title))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            @if (isset($task))
                            {{ __("app.update_tasks") }} : {{ $task->title }}
                            @else
                            {{ __("app.create_new_task") }}
                            @endif
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.module') }} : </b> {{ $module->name }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <form action="{{ route('task.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ isset($task) ? $task->id : '' }}" />
                    <input type="hidden" name="module_id" value="{{ $module->id }}" />
                    <input type="hidden" name="training_id" value="{{ $training->id }}" />
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="title" name="title" value="{{ old('title') ? : (isset($task) ? $task->title : '') }}" placeholder="{{ __('app.title') }}" required />
                                <label for="title">{{ __('app.title') }}</label>
                            </div>
                        </div>
                    </div>
                    @php
                    $data_type_checked_media = old('data_type') == 'media' ? 'checked' : (in_array($task->data_type, array('image', 'video', 'media')) ? 'checked' : '');
                    $data_type_checked_url = old('data_type') == 'url' ? 'checked' : (in_array($task->data_type, array('url')) ? 'checked' : '');
                    $data_type_checked_scorm = old('data_type') == 'scorm' ? 'checked' : (in_array($task->data_type, array('scorm')) ? 'checked' : '');
                    @endphp
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-label">
                                <label>{{ __('app.select_the_content_type_of_the_task')}} : </label>
                            </div>
                            <div class="form-check form-check-inline">
                                <input class="form-check-input data_type" type="radio" name="data_type" id="data_type_media" value="media" {{ $data_type_checked_media }} disabled>
                                <label class="form-check-label" for="data_type_media">{{ __('app.media_question') }}</label>
                            </div>
                            <div class="form-check form-check-inline">
                                <input class="form-check-input data_type" type="radio" name="data_type" id="data_type_url" value="url" {{ $data_type_checked_url }} disabled>
                                <label class="form-check-label" for="data_type_url">{{ __('app.url') }}</label>
                            </div>
                            @if ($training->category->id != 2)
                            <div class="form-check form-check-inline">
                                <input class="form-check-input data_type" type="radio" name="data_type" id="data_type_scorm" value="scorm" {{ $data_type_checked_scorm }} disabled>
                                <label class="form-check-label" for="data_type_scorm">{{ __('app.scorm') }}</label>
                            </div>
                            @endif
                        </div>
                    </div>
                    @if ($training->category->id != 2)
                    <div class="row div_documents div_task">
                        <div class="col-md-12 mt-3">
                            <div class="form-label">
                                <label>{{ __('app.link_training_documents')}} : </label>
                            </div>
                            <div class="form-floating mb-3">
                                <select class="form-select select2" id="documents" name="documents[]" aria-label="{{ __('app.link_training_documents') }}" multiple>
                                    @foreach ($training_documents as $key_doc => $val_doc)
                                    <option value="{{ $key_doc }}" {{ array_key_exists($key_doc, $documents) ? 'selected' : '' }}>{{ $key_doc }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row div_extra_link div_task">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="extra_link" name="extra_link" value="{{ isset($task) ? $task->extra_link : '' }}" placeholder="{{ __('app.additional_information_url') }}" />
                                <label for="extra_link">{{ __('app.additional_information_url') }}</label>
                            </div>
                        </div>
                    </div>
                    @endif
                    <div class="row div_data_path div_task">
                        <div class="col-md-12 mt-3">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="data_path" name="data_path" value="{{ old('data_path') ? : (isset($task) ? $task->data_path : '') }}" placeholder="{{ __('app.enter_external_url') }}" />
                                <label for="data_path">{{ __('app.enter_external_url') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row div_upload div_task mt-3" oncontextmenu="return false;">
                        <div class="col-md-12">
                            <div class="form">
                                <label class="form-label" for="upload">{{ __('app.upload') }}</label>
                                <input class="form-control mb-3" type="file" id="upload" name="upload" placeholder="{{ __('app.upload') }}">
                                <div class="text-center">
                                    @if ($task->data_type == 'image' && $data_path_name)
                                    <img src="{{ $data_path }}" style="max-width:70%;height:auto;" title="{{ $data_path_name }}">
                                    @endif
                                    @if ($task->data_type == 'video' && $data_path_name)
                                    <div class="ratio ratio-16x9">
                                        <iframe class="embed-responsive-item" src="{{ $data_path }}" title="{{ $data_path_name }}" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                                    </div>
                                    @endif
                                    @if ($task->data_type == 'url' && $data_path)
                                    <div class="embed-responsive embed-responsive-16by9">
                                        @if (strpos($data_path, 'iframe') !== false)
                                        {!! $data_path !!}
                                        @else
                                        <iframe class="embed-responsive-item" src="{{ $data_path }}" title="{{ $task->name }}" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                                        @endif
                                    </div>
                                    @endif
                                    @if ($task->data_type == 'media')
                                    <div class="image-container">
                                        @foreach ($data_path as $data_path_key => $data_path_val)
                                        <div>
                                            <img src="{{ $data_path_val }}" style="width:100%;height:auto;" title="{{ $data_path_key }}">
                                        </div>
                                        @endforeach
                                    </div>
                                    @endif
                                </div>
                            </div>
                        </div>
                    </div>
                    @if ($training->category->id != 2)
                    <div class="row div_question div_task mt-3">
                        <div class="col-md-12">
                            @if ($task->question)
                            <div class="form-floating">
                                <textarea class="form-control" id="question" name="question" placeholder="{{ __('app.question') }}" style="height: 115px;">{{ old('question') ? : ($task->question ? : '') }}</textarea>
                                <label for="question">{{ __('app.question') }}</label>
                            </div>
                            @else
                            <div class="form-check mt-3">
                                <input class="form-check-input" type="checkbox" id="question"" name=" question" value="yes">
                                <label class="form-check-label" for="question">
                                    {{ __('app.add_question') }}
                                </label>
                            </div>
                            @endif
                        </div>
                    </div>
                    @if ($task->question)
                    <div class="row mt-3 div_answer_type div_task">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="answer_type" name="answer_type" aria-label="{{ __('app.type_of_answer') }}" disabled>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    <option value="1" {{ $task->answer_type == 1 ? 'selected' : ''}}>{{ __('app.SingleChoice') }}</option>
                                    <option value="2" {{ $task->answer_type == 2 ? 'selected' : ''}}>{{ __('app.MultipleChoice') }}</option>
                                    <option value="3" {{ $task->answer_type == 3 ? 'selected' : ''}}>{{ __('app.Reorder') }}</option>
                                    <option value="4" {{ $task->answer_type == 4 ? 'selected' : ''}}>{{ __('app.Fill_in_the_blank') }}</option>
                                    <option value="5" {{ $task->answer_type == 5 ? 'selected' : ''}}>{{ __('app.Fill_in_a_number') }}</option>
                                    <option value="6" {{ $task->answer_type == 6 ? 'selected' : ''}}>{{ __('app.TimedSingleChoice') }}</option>
                                </select>
                                <label for="answer_type">{{ __('app.type_of_answer') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="card div_answers div_task">
                        <div class="card-body">
                            <div class="d-md-flex align-items-center justify-content-between">
                                <div class="mb-4 mb-md-0">
                                    <h4 class="card-title">
                                        {{ __("app.answers") }}
                                    </h4>
                                    <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($answers) }}</b> {{ __('app.items') }}</div>
                                </div>
                                <div class="d-flex align-items-center justify-content-between gap-6">
                                    <a href="{{ route('answer.create', [$locale, $training->id, $module->id, $task->id]) }}" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9">
                                        <i class="ti ti-plus fs-4"></i>
                                        {{ __("app.add_new") }}
                                    </a>
                                </div>
                            </div>
                            <div class="{{ $setting->table_div_class }}">
                                <table class="{{ $setting->table_class }}" id="training-module-list">
                                    <thead class="{{ $setting->table_thead_class }}">
                                        <tr>
                                            <th class="table-reference">#</th>
                                            <th>{{ __("app.answer") }}</th>
                                            <th>{{ __("app.correct") }}</th>
                                            <th>{{ __("app.feedback") }}</th>
                                            <th>{{ __("app.filename") }}</th>
                                            <th class="table-actions">{{ __("app.actions") }}</th>
                                        </tr>
                                    </thead>
                                    <tbody class="{{ $setting->table_tbody_class }}">
                                        @foreach ($answers as $answer)
                                        @php
                                        $action = route('answer.destroy', [$locale, $training->id, $module->id, $task->id]);
                                        $id = $answer->id;
                                        $title = $answer->answer;
                                        $message_question = __('message.confirmation_delete_item');
                                        $message_warning = "";
                                        @endphp
                                        <tr data-id="{{ $answer->id }}">
                                            <td class="table-reference">{{ $answer->id }}</td>
                                            <td>{{ $answer->answer }}</td>
                                            <td><i class="ti ti-{{ $answer->correct ? 'square-check' : 'square' }} fs-5"></i></td>
                                            <td>{{ $answer->feedback }}</td>
                                            <td>{{ $answer->filename }}</td>
                                            <td class="table-actions">
                                                <a href="{{ route('answer.edit', [$locale, $training->id, $module->id, $task->id, $answer->id]) }}" class="text-primary edit form-answer-edit">
                                                    <i class="ti ti-edit fs-5"></i>
                                                </a>
                                                <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $title }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                                    <i class="ti ti-trash fs-5"></i>
                                                </a>
                                            </td>
                                        </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                    @endif
                    @endif
                    <div class="form-actions">
                        <div class="card-body text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                            <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-danger ms-6">
                                <i class="ti ti-circle-x fs-4"></i>
                                {{ __('app.cancel') }}
                            </a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    // Dropzone.autoDiscover = false;
    $(function() {
        change_data_type();
    });

    function change_data_type() {
        var data_type = $("input[type='radio'][name='data_type']:checked").val();
        var div_task = $("div.div_task");
        var div_scorm_quiz_2004_version = $("div.div_scorm_quiz_2004_version");
        var div_scorm_version = $("div.div_scorm_version");
        var div_data_path = $("div.div_data_path");
        var div_upload = $("div.div_upload");
        var div_upload_scorm_package_zip_file = $("div.div_upload_scorm_package_zip_file");
        var div_question = $("div.div_question");
        var div_documents = $("div.div_documents");
        var div_extra_link = $("div.div_extra_link");
        var div_answer_type = $("div.div_answer_type");
        var div_answers = $("div.div_answers");
        div_task.hide();
        switch (data_type) {
            case "media":
                div_upload.show();
                div_question.show();
                div_documents.show();
                div_extra_link.show();
                div_answer_type.show();
                div_answers.show();
                break;
            case "url":
                div_data_path.show();
                div_documents.show();
                div_extra_link.show();
                break;
            case "scorm":
                div_scorm_quiz_2004_version.show();
                div_scorm_version.show();
                div_upload.show();
                div_upload_scorm_package_zip_file.show();
                div_question.show();
                div_documents.show();
                div_extra_link.show();
                break;
            default:
                div_documents.show();
                div_extra_link.show();
                break;
        }

        var question = "{{ $task->question }}";
    }
</script>

@endsection