@extends('layouts.app-bo')
@section('title', __('app.question') . ' : ' . $task->title)
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __("app.question") }} : {{ $task->title }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.module') }} : </b> {{ $module->name }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <form action="{{ route('task.question.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ $task->id }}" />
                    <input type="hidden" name="module_id" value="{{ $module->id }}" />
                    <input type="hidden" name="training_id" value="{{ $training->id }}" />
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="title" name="title" value="{{ $task->title }}" placeholder="{{ __('app.title') }}" required />
                                <label for="title">{{ __('app.title') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12 mb-3">
                            @if ($task->data_type == 'image')
                            <img src="{{ $data_path }}" style="max-width:70%;height:auto;">
                            @endif
                            @if ($task->data_type == 'video')
                            <div class="ratio ratio-16x9">
                                <iframe class="embed-responsive-item" src="{{ $data_path }}" title="{{ $data_path_name }}" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                            </div>
                            @endif
                            @if ($task->data_type == 'url')
                            <div class="embed-responsive embed-responsive-16by9">
                                @if (strpos($data_path, 'iframe') !== false)
                                {!! $data_path !!}
                                @else
                                <iframe class="embed-responsive-item" src="{{ $data_path }}" title="{{ $task->name }}" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                                @endif
                            </div>
                            @endif
                        </div>
                    </div>
                    @if ($task->question)
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating">
                                <textarea class="form-control" id="question" name="question" placeholder="{{ __('app.question') }}" style="height: 115px;">{{ old('question') ? : '' }}</textarea>
                                <label for="question">{{ __('app.question') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row div_reorder">
                        <div class="col-md-12">
                            <br />
                            <span class="mb-1 badge  bg-danger-subtle text-danger" style="padding: 20px;width: 100%;text-align: left;">
                                {{ __('app.type_of_answer_Reorder_warning') }}
                            </span>
                        </div>
                    </div>
                    <div class="row div_fill_in">
                        <div class="col-md-12">
                            <br />
                            <span class="mb-1 badge  bg-danger-subtle text-danger" style="padding: 20px;width: 100%;text-align: left;">
                                {{ __('app.type_of_answer_Fill_in_warning') }}
                            </span>
                        </div>
                    </div>
                    @endif
                    <div class="row">
                        <div class="col-md-12">
                            <br />
                            <div class="form-floating mb-3">
                                <select class="form-select" id="answer_type" name="answer_type" aria-label="{{ __('app.type_of_answer') }}" required>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    <option value="1">{{ __('app.SingleChoice') }}</option>
                                    <option value="2">{{ __('app.MultipleChoice') }}</option>
                                    <option value="3">{{ __('app.Reorder') }}</option>
                                    <option value="4">{{ __('app.Fill_in_the_blank') }}</option>
                                    <option value="5">{{ __('app.Fill_in_a_number') }}</option>
                                    <option value="6">{{ __('app.TimedSingleChoice') }}</option>
                                </select>
                                <label for="answer_type">{{ __('app.type_of_answer') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row div_duration">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="number" class="form-control" id="duration" name="duration" value="5" placeholder="{{ __('app.number_of_seconds_for_timer') }}" />
                                <label for="duration">{{ __('app.number_of_seconds_for_timer') }}</label>
                            </div>
                        </div>
                    </div>
                    @php
                    $action = route('task.destroy', [$locale, $module->id, $training->id]);
                    $id = $task->id;
                    $title = $task->title;
                    $message_question = __('message.confirmation_delete_item');
                    $message_warning = "";
                    @endphp
                    <div class="form-actions">
                        <div class="card-body border-top text-center">
                            <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $title }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="btn btn-danger ms-6">
                                <i class="ti ti-trash fs-5"></i>
                                {{ __('app.cancel') }}
                            </a>
                            <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-primary ms-6">
                                <i class="ti ti-message-off fs-4"></i>
                                {{ __('app.Finish_without_question') }}
                            </a>
                            <button type="submit" class="btn btn-success ms-6">
                                <i class="ti ti-message-plus fs-4"></i>
                                {{ __('app.Next_Answers') }}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    $(function() {
        $("select#answer_type").change(function() {
            var answer_type = $(this).val();
            if (answer_type == "3") {
                $("div.div_reorder").show();
            } else {
                $("div.div_reorder").hide();
            }
            if (answer_type == "4" || answer_type == "5") {
                $("div.div_fill_in").show();
            } else {
                $("div.div_fill_in").hide();
            }
            if (answer_type == "6") {
                $("div.div_duration").show();
            } else {
                $("div.div_duration").hide();
            }
        }).change();
    });
</script>

@endsection