@extends('layouts.app-bo')
@section('title', __('app.task') . ' : ' . $task->title)
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __("app.task") }} : {{ $task->title }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.module') }} : </b> {{ $module->name }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12 text-center">
                        @if ($task->data_type == 'image' && $data_path_name)
                        <img src="{{ $data_path }}" style="max-width:70%;height:auto;" title="{{ $data_path_name }}">
                        @endif
                        @if ($task->data_type == 'video' && $data_path_name)
                        <div class="text-center">
                            <video id="task-video"
                                src="{{ $data_path }}"
                                title="{{ $data_path_name }}"
                                controls=""
                                autoplay=""
                                controlslist="nodownload" style="width:75%;height:auto;margin:auto;display:block;">
                                {{ __('message.your_browser_does_not_support_the_video_tag') }}
                            </video>
                        </div>
                        @endif
                        @if ($task->data_type == 'url' && $data_path)
                        <div class="embed-responsive embed-responsive-16by9">
                            @if (strpos($data_path, 'iframe') !== false)
                            {!! $data_path !!}
                            @else
                            <div class="text-start mb-5">
                                <label>{{ __('app.provided_url') }}</label>
                                <div>{{ $data_path }}</div>
                            </div>
                            <iframe width="600" height="400" class="embed-responsive-item"
                                src="{{ $data_path }}" title="{{ $task->name }}"
                                allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                                allowfullscreen>
                            </iframe>
                            @endif
                        </div>
                        @endif
                        @if ($task->data_type == 'media')
                        <div class="image-container">
                            @foreach ($data_path as $data_path_key => $data_path_val)
                            <div>
                                <img src="{{ $data_path_val }}" style="width:100%;height:auto;" title="{{ $data_path_key }}">
                            </div>
                            @endforeach
                        </div>
                        @endif
                    </div>
                </div>
                @if ($training->category->id != 2)
                @if ($task->question /*&& $task->question != 'yes'*/)
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-floating">
                            <div class="form-control" placeholder="{{ __('app.question') }}" style="height: 115px;">{{ $task->question }}</div>
                            <label for="question">{{ __('app.question') }}</label>
                        </div>
                    </div>
                </div>
                @endif
                @if ($task->question || ($answers && count($answers)))
                <div class="d-md-flex align-items-center justify-content-between mt-7">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __("app.answers") }}
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($answers) }}</b> {{ __('app.items') }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">

                    </div>
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}" id="training-module-list">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("app.answer") }}</th>
                                <th>{{ __("app.correct") }}</th>
                                <th>{{ __("app.feedback") }}</th>
                                <th>{{ __("app.filename") }}</th>
                                <!-- <th class="table-actions">{{ __("app.actions") }}</th> -->
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($answers as $answer)
                            @php
                            $action = route('answer.destroy', [$locale, $training->id, $module->id, $task->id]);
                            $id = $answer->id;
                            $title = $answer->answer;
                            $message_question = __('message.confirmation_delete_item');
                            $message_warning = "";
                            @endphp
                            <tr data-id="{{ $answer->id }}">
                                <td class="table-reference">{{ $answer->id }}</td>
                                <td>{{ $answer->answer }}</td>
                                <td><i class="ti ti-{{ $answer->correct ? 'square-check' : 'square' }} fs-5"></i></td>
                                <td>{{ $answer->feedback }}</td>
                                <td>{{ $answer->filename }}</td>
                                <!-- 
                                <td class="table-actions">
                                    <a href="{{ route('answer.edit', [$locale, $training->id, $module->id, $task->id, $answer->id]) }}" class="text-primary edit form-answer-edit">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $title }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                                -->
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
                @endif
                @endif
                @if ($task->extra_link)
                <div class="mt-5 fs-3">
                    <b>{{ __('app.additional_information') }} : </b>
                    <div class="">
                        <a href="{{ $task->extra_link }}" target="_blank">{{ $task->extra_link }}</a>
                    </div>
                </div>
                @endif
                @if ($task->extra_link)
                <div class="mt-5 fs-3">
                    <b>{{ __('app.documents') }} : </b>
                    <div class="{{ $setting->table_div_class }}">
                        <table class="{{ $setting->table_class }}">
                            <tbody class="{{ $setting->table_tbody_class }}">
                                @foreach ($documents as $document_name => $document_path)
                                @php
                                $link_path = route('other.download', [$locale, $document_name]);
                                @endphp
                                <tr>
                                    <td>
                                        <a href="{{ $link_path }}">
                                            <h5>{{ $document_name }}</h5>
                                        </a>
                                    </td>
                                    <td class="table-actions">
                                        <a href="{{ $link_path }}" class="text-primary edit">
                                            <i class="ti ti-download fs-5"></i>
                                        </a>
                                        <a href="{{ str_replace('public/', '/storage/', $document_path) }}" target="_blank" class="text-primary edit">
                                            <i class="ti ti-eye fs-5"></i>
                                        </a>
                                    </td>
                                </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
                @endif
                <div class="form-actions mt-3">
                    <div class="card-body border-top text-center">
                        <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="btn btn-default ms-6">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __('app.ok') }}
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </section>
</div>

@endsection