@extends('layouts.app-bo')
@section('title', $training_report->id ? (__('app.update_training_report') . ' : ' . $training_report->name) : __('app.create_training_report'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card" id="training-report">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="akar-icons:statistic-up"></iconify-icon>
                            {{ $training_report->id ? __('app.update_training_report') : __('app.create_training_report') }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.name') }} : </b> {{ $training_report->name }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training-report.list', $locale) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <br />
                <form action="{{ route('training-report.store', $locale) }}" method="POST" enctype="multipart/form-data" onsubmit="return validation()" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ $training_report->id }}" />
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="name" name="name" placeholder="{{ __('app.name') }}" value="{{ $training_report->name }}" />
                                <label for="name">{{ __('app.name') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="start_date" name="start_date" placeholder="{{ __('app.start_date') }}" value="{{ $training_report->start_date }}" />
                                <label for="start_date">{{ __('app.start_date') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="date_interval" name="date_interval" aria-label="{{ __('app.date_interval') }}">
                                    @foreach ($date_intervals as $key => $val)
                                    <option value="{{ $key }}" {{ $key == $training_report->date_interval ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="date_interval">{{ __('app.date_interval') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row date">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="date" name="date" placeholder="{{ __('app.date') }}" value="{{ $training_report->date }}" />
                                <label for="date">{{ __('app.date') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="description" name="description" placeholder="{{ __('app.description') }}" style="height: 80px;">{{ $training_report->description }}</textarea>
                                <label for="description">{{ __('app.description') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-check mb-3">
                                <label class="form-check-label" for="scheduled">
                                    {{ __('app.scheduled') }}
                                    <input type="checkbox" class="form-check-input" id="scheduled" name="scheduled" value="1" placeholder="{{ __('app.scheduled') }}" {{ $training_report->scheduled ? 'checked' : '' }}>
                                </label>
                            </div>
                        </div>
                    </div>
                    <div class="row recipients">
                        <div class="col-md-12">
                            <div class="form mb-3">
                                <label for="recipients">{{ __('app.recipients') }}</label>
                                <select class="form-select select2" id="recipients" name="recipients[]" aria-label="{{ __('app.recipients') }}" multiple="multiple">
                                    @foreach ($users as $user)
                                    <option value="{{ $user->id }}" {{ in_array($user->id, $training_report->recipients) ? 'selected' : '' }}>
                                        {{ $user->lname }}, {{ $user->fname }} [{{ $user->ref }}]
                                    </option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    @if ($training_report->filter_by)
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="filter_by" name="filter_by" aria-label="{{ __('app.date_filter') }}">
                                    @foreach ($date_filters as $key => $val)
                                    <option value="{{ $key }}" {{ $key == $training_report->filter_by ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="filter_by">{{ __('app.date_filter') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form mb-3">
                                <label class="ms-3 mb-1" for="trainings">{{ __('app.trainings') }}</label>
                                <select class="form-select select2" id="trainings" name="trainings[]" aria-label="{{ __('app.trainings') }}" multiple required>
                                    @foreach ($training_list as $training)
                                    <option value="{{ $training->id }}" {{ in_array($training->id, $training_report->trainings) ? 'selected' : '' }}>
                                        [{{ $training->prefix }}] - {{ $training->name }}
                                    </option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form mb-3">
                                <label class="ms-3 mb-1" for="results">{{ __('app.results') }}</label>
                                <select class="form-select select2" id="results" name="results[]" aria-label="{{ __('app.results') }}" multiple required>
                                    @foreach ($result_list as $key => $val)
                                    <option value="{{ $key }}" {{ in_array($key, $training_report->results) ? 'selected' : '' }}>
                                        {{ $val }}
                                    </option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    @endif
                    <div class="form-actions">
                        <div class="card-body text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    $(document).ready(function() {
        add_select_all('recipients');
        add_select_all('trainings');
        add_select_all('results');

        $("#date_interval").change(function() {
            var date_interval = $(this).val();
            if (date_interval == "7") {
                $("div.date").fadeIn().show();
            } else {
                $("div.date").fadeOut().hide();
            }
        }).change();

        $("#scheduled").change(function() {
            var scheduled = $(this).is(":checked");
            if (scheduled) {
                $("div.recipients").fadeIn().show();
            } else {
                $("div.recipients").fadeOut().hide();
            }
        }).change();
    });

    function validation() {
        return true;
    }

    function add_select_all(id) {
        $('#' + id).select2({
            placeholder: "{{ __('app.select') }} ...",
            allowClear: true
        });

        const selectAllOption = new Option("{{ __('app.select_all') }}", 'select_all');
        $('#' + id).prepend(selectAllOption).trigger('change');

        $('#' + id).on('select2:select', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option:not([value="select_all"])').prop('selected', true).trigger('change');
            }
        });

        $('#' + id).on('select2:unselect', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option').prop('selected', false).trigger('change');
            }
        });
    }
</script>
@endsection