@extends('layouts.app-bo')
@section('title', $training_subreport->id ? (__('app.update_training_subreport') . ' : ' . $training_subreport->name) : __('app.create_training_subreport'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card" id="training-subreport">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="akar-icons:statistic-up"></iconify-icon>
                            {{ $training_subreport->id ? __('app.update_training_subreport') : __('app.create_training_subreport') }}
                        </h4>
                        @if ($training_subreport->id)
                        <div class="mb-3 card-subtitle"><b>{{ __('app.name') }} : </b> {{ $training_subreport->name }}</div>
                        @endif
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training-report.view', [$locale, $training_subreport->training_report_id]) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <br />
                <form action="{{ route('training-subreport.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="id" value="{{ $training_subreport->id }}" />
                    <input type="hidden" name="training_report_id" value="{{ $training_subreport->training_report_id }}" />
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="name" name="name" placeholder="{{ __('app.name') }}" value="{{ $training_subreport->name }}" required />
                                <label for="name">{{ __('app.name') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-1">
                                <textarea class="form-control" id="description" name="description" placeholder="{{ __('app.description') }}" style="height: 80px;">{{ $training_subreport->description }}</textarea>
                                <label for="description">{{ __('app.description') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <label class="m-3">{{ __('app.subreport_date_interval') }}</label>
                            <span class="mb-3 badge bg-primary-subtle text-primary" style="padding: 20px;width: 100%;text-align: left;">
                                {{ __('message.subreport_date_interval_badge') }}
                            </span>
                        </div>
                    </div>
                    @if (!$training_subreport->id)
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="date_interval" name="date_interval" aria-label="{{ __('app.date_interval') }}" required>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($date_intervals as $key => $val)
                                    <option value="{{ $key }}" {{ $key == $training_subreport->date_interval ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="date_interval">{{ __('app.date_interval') }}</label>
                            </div>
                        </div>
                    </div>
                    @endif
                    <div class="row">
                        <div class="col-md-6 start_date">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="start_date" name="start_date" placeholder="{{ __('app.start_date') }}" value="{{ $training_subreport->start_date }}" required />
                                <label for="start_date">{{ __('app.start_date') }} ({{ __('app.inclusive')}})</label>
                            </div>
                        </div>
                        <div class="col-md-6 end_date">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control" id="end_date" name="end_date" placeholder="{{ __('app.end_date') }}" value="{{ $training_subreport->end_date }}" />
                                <label for="end_date">{{ __('app.end_date') }} ({{ __('app.inclusive')}})</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="filter_type" name="filter_type" aria-label="{{ __('app.filter_type') }}" required>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($filter_types as $key => $val)
                                    <option value="{{ $key }}" {{ $key == $training_subreport->filter_type ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="filter_type">{{ __('app.filter_type') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="filter_metric" name="filter_metric" aria-label="{{ __('app.result_metric') }}" required>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($filter_metrics as $key => $val)
                                    <option value="{{ $key }}" {{ $key == $training_subreport->filter_metric ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="filter_metric">{{ __('app.result_metric') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="filter_output" name="filter_output" aria-label="{{ __('app.result_output') }}" required>
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($filter_outputs as $key => $val)
                                    <option value="{{ $key }}" {{ $key == $training_subreport->filter_output ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                                <label for="filter_metric">{{ __('app.result_output') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form mb-3">
                                <label class="ms-3 mb-1" for="multiple_filters">{{ __('app.report_filtering_select_up_to_2_filters_in_the_order_you_want') }}</label>
                                <select class="form-select" id="multiple_filters" name="multiple_filters[]" aria-label="{{ __('app.report_filtering_select_up_to_2_filters_in_the_order_you_want') }}" multiple required>
                                    @foreach ($multiple_filters as $key => $val)
                                    <option value="{{ $key }}" {{ in_array($key, $training_subreport->multiple_filters) ? 'selected' : '' }}>{{ $val }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="category_id" name="category_id" aria-label="{{ __('app.category') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    <option value="0">{{ __('app.all') }}</option>
                                    @foreach ($categories as $category)
                                    <option value="{{ $category->id }}" {{ $category->id == $training_subreport->category_id ? 'selected' : '' }}>
                                        {{ __("menus.$category->code") }}
                                    </option>
                                    @endforeach
                                </select>
                                <label for="category_id">{{ __('app.category_for_the_report_if_you_select_a_category_you_cannot_select_a_training') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="training_id" name="training_id" aria-label="{{ __('app.training') }}">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($trainings as $training)
                                    <option value="{{ $training->id }}" {{ $training->id == $training_subreport->training_id ? 'selected' : '' }}>
                                        {{ __("menus." . $training->category->code) }} - [{{ $training->prefix }}] - {{ $training->name }}
                                    </option>
                                    @endforeach
                                </select>
                                <label for="training_id">{{ __('app.training_for_the_report') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="form-actions">
                        <div class="card-body text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    $(document).ready(function() {
        $("#date_interval").change(function() {
            var date_interval = $(this).val();
            if (date_interval == "7") {
                $("div.end_date").fadeIn().show();
                $("#end_date").attr("required", true);
            } else {
                $("div.end_date").fadeOut().hide();
                $("#end_date").removeAttr("required");
            }
        }).change();

        $('#multiple_filters').select2({
            maximumSelectionLength: 2,
            language: {
                maximumSelected: function() {
                    return "{{ __('message.select_up_to_2_options') }}";
                }
            }
        });

        $("#category_id").change(function() {
            var category_id = $(this).val();
            if (category_id != "") {
                $("#training_id").val("").change();
                $("#training_id").attr("disabled", true);
            } else {
                $("#training_id").removeAttr("disabled");
            }
        }).change();

        $("#category_id, #training_id").attr("disabled", true);
        $("#multiple_filters").change(function() {
            var multiple_filters = $(this).val();
            if (multiple_filters.length) {
                $("#category_id, #training_id").removeAttr("disabled");
            } else {
                $("#category_id, #training_id").attr("disabled", true);
            }
        }).change();

        var id = '{{ $training_subreport->id }}';
        if (id) {
            $("#category_id").change();
        }

        $("#start_date").change(function() {
            var start_date = $(this).val();
            date = new Date(start_date);
            date.setMonth(date.getMonth() + 3);
            var end_date = date.toISOString().split('T')[0];
            $("#end_date").attr("max", end_date);
        }).change();
    });

    function add_select_all(id) {
        $('#' + id).select2({
            placeholder: "{{ __('app.select') }} ...",
            allowClear: true
        });

        const selectAllOption = new Option("{{ __('app.select_all') }}", 'select_all');
        $('#' + id).prepend(selectAllOption).trigger('change');

        $('#' + id).on('select2:select', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option:not([value="select_all"])').prop('selected', true).trigger('change');
            }
        });

        $('#' + id).on('select2:unselect', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option').prop('selected', false).trigger('change');
            }
        });
    }
</script>
@endsection