@extends('layouts.app-bo')
@section('title', __('app.training_details'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card" id="user-training">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __('app.training_details') }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.category') }} : </b> {{ __('menus.' . $type) }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('statistic.user-training.export', array_merge(['locale' => $locale], request()->all())) }}" class="btn btn-secondary d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-file-export fs-4"></i>
                            {{ __("app.export") }}
                        </a>
                        <a href="{{ route('training-report.list', $locale) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <br />
                <div class="row">
                    <div class="col-md-6 text-end">
                        <b>{{ __('app.start_date') }} ({{ __('app.inclusive') }}) : </b>
                        <span>{{ $start_date }}</span>
                    </div>
                    <div class="col-md-6 text-start">
                        <b>{{ __('app.end_date') }} ({{ __('app.inclusive') }}) : </b>
                        <span>{{ $end_date ?? ' - ' }}</span>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}" id="training-subreport-list">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th>{{ __("app.trainee") }}</th>
                                <th class="text-center">{{ __("app.status") }}</th>
                                <th class="text-center">{{ __("app.start") }}</th>
                                <th class="text-center">{{ __("app.progress") }}</th>
                                <th class="text-center">{{ __("app.attestation") }}</th>
                                <th>{{ __("app.training") }}</th>
                                <th class="text-center">{{ __("app.time_taken") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($user_trainings as $user_training)
                            @php
                            $training = $user_training->training;
                            $user = $user_training->user;
                            if (!$training->name) continue;
                            $progress = $user_training->progress;
                            $bg_progress = $progress >= 91 && $progress <= 100 ? "bg-success" : "";
                            $bg_progress = $progress >= 11 && $progress <= 90 ? "bg-warning" : $bg_progress;
                            $bg_progress = $progress >= 0 && $progress <= 10 ? "bg-danger" : $bg_progress;
                            @endphp
                            <tr>
                                <td>{{ $user->fname }} {{ $user->lname }}</td>
                                <td class="text-center">
                                    <i class="ti ti-{{ $user_training->active ? 'circle-check text-success' : 'circle-x text-danger' }} fs-4"></i>
                                </td>
                                <td class="text-center {{ $bg_progress }}">{{ $user_training->assigned_date }}</td>
                                <td class="text-center {{ $bg_progress }}">{{ $user_training->progress }}%</td>
                                <td class="text-center {{ $bg_progress }}">
                                    @if ($user_training->attestation)
                                    <div>
                                        <i class="ti ti-circle-check fs-4"></i>
                                        <br />
                                        {{ $user_training->attest_date }}
                                    </div>
                                    @endif
                                    @if ($user_training->certification)
                                    <div>
                                        <i class="ti ti-star fs-4"></i>
                                        <br />
                                        {{ $user_training->cert_date }}
                                    </div>
                                    @endif
                                </td>
                                <td>{{ $training->name }}</td>
                                <td class="text-center">
                                    {{ App\Helper\Times::sec_to_time_full($user_training->th_duration_taken + $user_training->pr_duration_taken) }}
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
            <br />
        </div>
        <div class="card" id="user-training">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __('app.memo') }}
                        </h4>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6 text-center">
                        <div class="row">
                            <div class="col-md-4"></div>
                            <div class="col-md-2 text-center "><strong>{{ __('app.color') }}</strong></div>
                            <div class="col-md-6 text-start"><strong>{{ __('app.score') }}</strong></div>
                        </div>
                        <div class="row">
                            <div class="col-md-4"></div>
                            <div class="col-md-2 text-end bg-success"></div>
                            <div class="col-md-6 text-start">91% - 100%</div>
                        </div>
                        <div class="row">
                            <div class="col-md-4"></div>
                            <div class="col-md-2 text-end bg-warning"></div>
                            <div class="col-md-6 text-start">11% - 90%</div>
                        </div>
                        <div class="row">
                            <div class="col-md-4"></div>
                            <div class="col-md-2 text-end bg-danger"></div>
                            <div class="col-md-6 text-start">0% - 10%</div>
                        </div>
                    </div>
                    <div class="col-md-6 text-center">
                        <br />
                        <div class="row">
                            <div class="col-md-6 text-end">{{ __('app.attestation') }}</div>
                            <div class="col-md-6 text-start"><i class="ti ti-circle-check fs-4"></i></div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 text-end">{{ __('app.certification') }}</div>
                            <div class="col-md-6 text-start"><i class="ti ti-star fs-4"></i></div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Javascript -->
<script type="text/javascript">
    $(document).ready(function() {

    });
</script>
@endsection