@extends('layouts.app-bo')
@section('title', __('app.training_report') . ' : ' . $training_report->name)
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card" id="training-report">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="akar-icons:statistic-up"></iconify-icon>
                            {{ $training_report->name }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.description') }} : </b> {{ $training_report->description }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training-report.generate', [$locale, $training_report->id]) }}" class="btn btn-secondary">
                            <i class="ti ti-report-analytics fs-4"></i>
                            {{ __('app.generate_and_email_report') }}
                        </a>
                        <a href="{{ route('training-report.list', $locale) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <hr />
                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-6">{{ __('app.name') }} :</label>
                            <div class="col-md-6">
                                <p class="form-control-static">{{ $training_report->name }}</p>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-6">{{ __('app.scheduled') }} :</label>
                            <div class="col-md-6">
                                <p class="form-control-static">
                                    @if ($training_report->scheduled)
                                    <i class="ti ti-check fs-6 text-success"></i>
                                    @else
                                    <i class="ti ti-x fs-6 text-danger"></i>
                                    @endif
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-6">{{ __('app.start_date') }} :</label>
                            <div class="col-md-6">
                                <p class="form-control-static">{{ $training_report->start_date }}</p>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-6">{{ __('app.end_date_period') }} :</label>
                            <div class="col-md-6">
                                <p class="form-control-static">
                                    @if ($training_report->date_interval == "7")
                                    {{ $training_report->date }}
                                    @else
                                    {{ $date_intervals[$training_report->date_interval] }}
                                    @endif
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-3">{{ __('app.description') }} :</label>
                            <div class="col-md-9">
                                <p class="form-control-static">{{ $training_report->description }}</p>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-3">{{ __('app.recipients') }} :</label>
                            <div class="col-md-9">
                                <p class="form-control-static">
                                    @foreach ($training_report->recipients as $user)
                                    <span class="mb-1 badge text-bg-light">
                                        {{ $user->lname }}, {{ $user->fname }} [{{ $user->ref }}]
                                    </span>
                                    @endforeach
                                    @if (!count($training_report->recipients))
                                    -
                                    @endif
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
                @if ($training_report->filter_by)
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-3">{{ __('app.trainings') }} :</label>
                            <div class="col-md-9">
                                <p class="form-control-static">
                                    @foreach ($training_report->trainings as $training)
                                    <span class="mb-1 badge text-bg-light">
                                        [{{ $training->prefix }}] - {{ $training->name }}
                                    </span>
                                    @endforeach
                                    @if (!count($training_report->trainings))
                                    -
                                    @endif
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group row">
                            <label class="form-label text-end col-md-3">{{ __('app.results') }} :</label>
                            <div class="col-md-9">
                                <p class="form-control-static">
                                    @foreach ($training_report->results as $result)
                                    <span class="mb-1 badge text-bg-light">
                                        {{ $result }}
                                    </span>
                                    @endforeach
                                    @if (!count($training_report->results))
                                    -
                                    @endif
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
                @endif
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __('app.sub_reports') }}
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($training_report->training_subreports) }}</b> {{ __('app.items') }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training-subreport.create', [$locale, $training_report->id]) }}" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create") }}
                        </a>
                    </div>
                </div>
            </div>
            <div class="{{ $setting->table_div_class }}">
                <table class="{{ $setting->table_class }}" id="training-subreport-list">
                    <thead class="{{ $setting->table_thead_class }}">
                        <tr>
                            <th class="table-reference"></th>
                            <th class="table-reference">#</th>
                            <th>{{ __("app.name") }}</th>
                            <th>{{ __("app.description") }}</th>
                            <th>{{ __("app.start_date") }}</th>
                            <th>{{ __("app.end_date") }}</th>
                            <th>{{ __("app.filter_type") }}</th>
                            <th>{{ __("app.filters") }}</th>
                            <th>{{ __("app.type") }}</th>
                            <th>{{ __("app.metric") }}</th>
                            <th class="table-actions sticky-search-button">{{ __("app.actions") }}</th>
                        </tr>
                    </thead>
                    <tbody class="{{ $setting->table_tbody_class }}">
                        @foreach ($training_subreports as $training_subreport)
                        @php
                        $action = route('training-subreport.destroy', [$locale, $training_subreport->id]);
                        $id = $training_subreport->id;
                        $name = $training_subreport->name;
                        $message_question = __('message.confirmation_delete_item');
                        $message_warning = "";
                        @endphp
                        <tr data-id="{{ $training_subreport->id }}">
                            <td class="table-reference drag-handle" style="cursor: move;"><i class="ti ti-arrows-up-down fs-5"></i></td>
                            <td class="table-reference">{{ $training_subreport->id }}</td>
                            <td>{{ $training_subreport->name }}</td>
                            <td>{{ $training_subreport->description }}</td>
                            <td>{{ $training_subreport->start_date }}</td>
                            <td>{{ $training_subreport->end_date }}</td>
                            <td>{{ $filter_types[$training_subreport->filter_type] }}</td>
                            <td>
                                @foreach ($training_subreport->filters['filters'] as $filter)
                                <div>{{ $multiple_filters[$filter] }}</div>
                                @endforeach
                            </td>
                            <td>{{ $training_subreport->filters['output'] }}</td>
                            <td>{{ $training_subreport->filters['metric'] }}</td>
                            <td class="table-actions sticky-search-button">
                                <a href="{{ route('training-subreport.edit', [$locale, $training_subreport->id]) }}" class="text-primary edit form-training-subreport-edit">
                                    <i class="ti ti-edit fs-5"></i>
                                </a>
                                <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                    <i class="ti ti-trash fs-5 text-danger"></i>
                                </a>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
            <br />
        </div>
    </section>
</div>

<!-- Javascript -->
<script type="text/javascript">
    $(document).ready(function() {
        add_select_all('recipients');

        $("#date_interval").change(function() {
            var date_interval = $(this).val();
            if (date_interval == "7") {
                $("div.date").fadeIn().show();
            } else {
                $("div.date").fadeOut().hide();
            }
        }).change();

        $("#scheduled").change(function() {
            var scheduled = $(this).is(":checked");
            if (scheduled) {
                $("div.recipients").fadeIn().show();
            } else {
                $("div.recipients").fadeOut().hide();
            }
        }).change();

        $("table#training-subreport-list tbody").sortable({
            handle: ".drag-handle",
            items: "tr",
            cursor: "move",
            placeholder: "ui-state-highlight",
            start: function(e, ui) {
                ui.placeholder.height(ui.item.height());
            },
            update: function(event, ui) {
                var elements = $(this).sortable('toArray', {
                    attribute: 'data-id'
                });
                $.ajax({
                    url: '{{ route("training-subreport.update.order", [$locale]) }}',
                    type: 'POST',
                    data: {
                        _token: '{{ csrf_token() }}',
                        training_report_id: '{{ $training_report->id }}',
                        ids: elements
                    },
                    dataType: 'json',
                    success: function() {
                        toastr.success(
                            "success",
                            "{{ __('message.order_updated') }}", {
                                showMethod: "fadeIn",
                                hideMethod: "fadeOut",
                                timeOut: 1000,
                                closeButton: true
                            }
                        );
                    }
                });
            }
        });
        $("#table#training-subreport-list tbody").disableSelection();
    });

    function validation() {
        return true;
    }

    function add_select_all(id) {
        $('#' + id).select2({
            placeholder: "{{ __('app.select') }} ...",
            allowClear: true
        });

        const selectAllOption = new Option("{{ __('app.select_all') }}", 'select_all');
        $('#' + id).prepend(selectAllOption).trigger('change');

        $('#' + id).on('select2:select', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option:not([value="select_all"])').prop('selected', true).trigger('change');
            }
        });

        $('#' + id).on('select2:unselect', function(e) {
            if (e.params.data.id === 'select_all') {
                $('#' + id).find('option').prop('selected', false).trigger('change');
            }
        });
    }
</script>
@endsection