@extends('layouts.app-bo')
@section('title', __('app.live_reading'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card shadow">
            <div class="card-header bg-light py-3">
                <h4 class="mb-0"><i class="fas fa-users me-2"></i>{{ __('app.live_reading') }}</h4>
            </div>
            <div class="card-body p-4">
                
                <form id="thisForm" method="POST" action="{{ route('trainings.select-trainee', ['locale' => $locale, 'category_id' => $category_id, 'training_id' => $training_id]) }}">
                    @csrf
                    <div class="card shadow-sm h-100">
                        <div class="card-body">
                            <div class="row g-3">
                                <div class="col-md-4">
                                    <label class="form-label fw-bold">{{ __('app.department') }}</label>
                                    <select name="departments" id="departments" class="form-select select2">
                                        <option value="">{{ __('app.select_department') }}</option>
                                        @foreach($departments as $department)
                                            <option value="{{ $department->id }}" {{ request('departments') == $department->id ? 'selected' : '' }}>{{ $department->name }}</option>
                                        @endforeach
                                    </select>
                                </div>

                                <div class="col-md-5">
                                    <label class="form-label fw-bold">{{ __('app.subdepartment') }}</label>
                                    <select name="subdepartments" id="subdepartments" class="form-select select2">
                                        <option value="">{{ __('app.select_subdepartment') }}</option>
                                        @foreach($subdepartments as $subdepartment)
                                            <option value="{{ $subdepartment->id }}" {{ request('subdepartments') == $subdepartment->id ? 'selected' : '' }}>{{ $subdepartment->name }}</option>
                                        @endforeach
                                    </select>
                                </div>

                                <div class="col-md-3">
                                    <label class="form-label fw-bold">{{ __('app.location') }}</label>
                                    <select name="locations" id="locations" class="form-select select2">
                                        <option value="">{{ __('app.select_location') }}</option>
                                        @foreach($locations as $location)
                                            <option value="{{ $location->id }}" {{ request('locations') == $location->id ? 'selected' : '' }}>{{ $location->name }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>

                            <div class="row mt-3">
                                <div class="col-12">
                                    <div class="input-group">
                                        <span class="input-group-text"><i class="fas fa-search"></i></span>
                                        <input type="text" name="search" class="form-control" placeholder="{{ __('app.search_by_name_or_family_name_or_matricule_id') }}" value="{{ request('search') }}">
                                    </div>
                                </div>
                            </div>

                            <div class="row mt-3">
                                <div class="col-md-6">
                                    <button type="submit" id="search" class="btn btn-primary w-100 shadow-sm">
                                        <i class="fas fa-search me-2"></i>{{ __('app.search') }}
                                    </button>
                                </div>
                                <div class="col-md-6">
                                    <button type="submit" id="reset" name="reset" value="reset" class="btn btn-outline-secondary w-100 shadow-sm" onclick="resetFilters(event)">
                                        <i class="fas fa-redo me-2"></i>{{ __('app.reset') }}
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                    </div>
                    <div class="row mt-4">
                        <div class="col-lg-5">                         
                            <div class="card shadow-sm h-100">
                                <div class="card-header bg-light py-3">
                                    <h5 class="mb-0"></i>{{ __('app.available_users') }}</h5>
                                </div>
                                <div class="card-body">                                
                                    <div class="row">
                                        <div class="col-12">
                                            <div class="d-flex justify-content-between align-items-center mb-2">
                                                <div class="form-check">
                                                    <input type="checkbox" id="selectAllAvailable" class="form-check-input" onclick="toggleAllAvailable()">
                                                    <label class="form-check-label" for="selectAllAvailable">{{ __('app.select_all_available') }}</label>
                                                </div>
                                            </div>
                                            <div class="list-group border rounded" style="height:400px; overflow-y:auto;">
                                                @foreach($availUsers as $id => $name)
                                                    <div class="list-group-item list-group-item-action">
                                                        <input type="checkbox" name="available_users[]" id="available_user_{{ $id }}" value="{{ $id }}" class="form-check-input me-2" onchange="user_selected()">
                                                        <label for="available_user_{{ $id }}" class="form-check-label">{{ $name }}</label>
                                                    </div>
                                                @endforeach
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="col-lg-3">
                            <div class="card shadow-sm text-center h-100">
                                <div class="card-body d-flex flex-column justify-content-center">
                                    <div class="mb-4">
                                        <h5 class="fw-bold text-muted mb-2">{{ __('app.selected_users') }}</h5>
                                        <h3 id="selected_users" class="text-primary mb-0">0</h3>
                                    </div>

                                    <button type="button" class="btn btn-success mb-3 shadow-sm" onclick="addParticipant()">
                                        {{ __('app.add') }} <i class="fas fa-arrow-right ms-2"></i>
                                    </button>
                                    
                                    <button type="button" class="btn btn-danger mb-4 shadow-sm" onclick="removeParticipant()">
                                        <i class="fas fa-arrow-left me-2"></i>{{ __('app.remove') }}
                                    </button>
                                    
                                    <div id="reader" class="mb-3"></div>
                                    
                                    <div class="input-group">
                                        <span class="input-group-text"><i class="fas fa-qrcode"></i></span>
                                        <input type="text" name="matriculeID" id="matriculeID" placeholder="{{ __('app.scan_code') }}" class="form-control text-center" autocomplete="off" autofocus>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="col-lg-4">
                            <div class="card shadow-sm h-100">
                                <div class="card-header bg-light py-3">
                                    <h5 class="mb-0"><i class="fas fa-user-check me-2"></i>{{ __('app.selected_members') }}</h5>
                                </div>
                                <div class="card-body">
                                    <div class="d-flex justify-content-between align-items-center mb-2">
                                        <div class="form-check">
                                            <input type="checkbox" id="selectAllMembers" class="form-check-input" onclick="toggleAllMembers()">
                                            <label class="form-check-label" for="selectAllMembers">{{ __('app.select_all_members') }}</label>
                                        </div>
                                    </div>
                                    <div class="list-group members-container border rounded" style="height:400px; overflow-y:auto;">
                                        @forelse($members ?? [] as $id => $name)
                                            <div class="list-group-item list-group-item-action">
                                                <input type="checkbox" name="live_members[]" value="{{ $id }}" class="form-check-input me-2">
                                                <label class="form-check-label">{{ $name }}</label>
                                            </div>
                                        @empty
                                            <div class="list-group-item">{{ __('app.no_members_selected') }}</div>
                                        @endforelse
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row mt-4">
                        <div class="col-lg-6 offset-lg-3">
                            <div class="card shadow-sm">
                                <div class="card-body">
                                    <label class="form-label fw-bold">{{ __('app.select_group_label') }}</label>
                                    <select name="groupID" id="groupID" class="form-select" onchange="groupSelect(this)">
                                        <option value="">{{ __('app.select') }}</option>
                                        @foreach($userGroups as $id => $name)
                                            <option value="{{ $id }}">{{ $name }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row mt-4 mb-3 text-center">
                        <div class="col-12">
                            <a href="{{ route('trainings.live_reading', ['locale' => app()->getLocale()]) }}" class="btn btn-secondary me-3 shadow-sm">
                                <i class="fas fa-arrow-left me-2"></i>{{ __('app.back') }}
                            </a>

                            <button type="submit" class="btn btn-primary shadow-sm" onclick="sendSubmit(this)">
                                <i class="fas fa-play me-2"></i>{{ __('app.start_live_reading') }}
                            </button>
                        </div>
                    </div>
                </form>

                <div id="snackbar"></div>

                <script src="https://unpkg.com/html5-qrcode"></script>

                <style>
                    #snackbar {
                        visibility: hidden;
                        min-width: 400px;
                        margin-left: -200px;
                        background-color: #28a745;
                        color: #fff;
                        text-align: center;
                        border-radius: 8px;
                        padding: 16px;
                        position: fixed;
                        z-index: 1050;
                        left: 50%;
                        bottom: 100px;
                        box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15);
                    }

                    #snackbar.show {
                        visibility: visible;
                        -webkit-animation: fadein 0.5s, fadeout 0.5s 2.5s;
                        animation: fadein 0.5s, fadeout 0.5s 2.5s;
                    }

                    @-webkit-keyframes fadein {
                        from {bottom: 0; opacity: 0;}
                        to {bottom: 100px; opacity: 1;}
                    }

                    @keyframes fadein {
                        from {bottom: 0; opacity: 0;}
                        to {bottom: 100px; opacity: 1;}
                    }

                    @-webkit-keyframes fadeout {
                        from {bottom: 100px; opacity: 1;}
                        to {bottom: 0; opacity: 0;}
                    }

                    @keyframes fadeout {
                        from {bottom: 100px; opacity: 1;}
                        to {bottom: 0; opacity: 0;}
                    }

                    .select2-container .select2-selection--single {
                        height: 38px !important;
                    }

                    .select2-container--default .select2-selection--single .select2-selection__rendered {
                        line-height: 38px !important;
                    }

                    .select2-container--default .select2-selection--single .select2-selection__arrow {
                        height: 36px !important;
                    }

                    .list-group-item-action:hover {
                        background-color: #f8f9fa;
                    }

                    .card {
                        border: none;
                        transition: transform 0.2s;
                    }

                    .card:hover {
                        transform: translateY(-2px);
                    }
                </style>

                <script>
                    var lastResult, countResults = 0;
                    const form = document.getElementById('thisForm');
                    const codeScanner = document.getElementById('matriculeID');

                    function toggleAllAvailable() {
                        let checkboxes = document.getElementsByName('available_users[]');
                        let checked = document.getElementById('selectAllAvailable').checked;
                        checkboxes.forEach(function(checkbox) {
                            checkbox.checked = checked;
                        });
                        user_selected();
                    }

                    function toggleAllMembers() {
                        let checkboxes = document.getElementsByName('live_members[]');
                        let checked = document.getElementById('selectAllMembers').checked;
                        checkboxes.forEach(function(checkbox) {
                            checkbox.checked = checked;
                        });
                    }

                    function toast(data, success, duration) {
                        var x = document.getElementById("snackbar");
                        x.style.backgroundColor = success ? "#28a745" : "#6c757d";
                        x.innerText = data;
                        x.className = "show";
                        setTimeout(function(){ x.className = x.className.replace("show", ""); }, duration);
                    }

                    function user_selected(){
                        let selected = 0;
                        let checkboxes = document.getElementsByName('available_users[]');
                        checkboxes.forEach(function(checkbox){
                            if(checkbox.checked) {
                                selected++;
                            }
                        });
                        document.getElementById('selected_users').innerText = selected;
                    }

                    function scanSuccess(data, showToast){
                        let checkboxes = document.getElementsByName('available_users[]');
                        checkboxes.forEach(function(checkbox) {
                            if(checkbox.value === data) {
                                checkbox.checked = true;
                                addParticipant();
                                if(showToast) {
                                    toast(checkbox.nextElementSibling.textContent + " {{ __('app.successfully_added') }}", true, 3000);
                                }
                                document.getElementById('selected_users').innerText++;
                            }
                        });
                    }

                    function addParticipant(){
                        let availableUsers = document.getElementsByName('available_users[]');
                        let membersContainer = document.querySelector('.members-container');
                        
                        // Remove "no members selected" message if it exists
                        if(membersContainer.children.length === 1 && membersContainer.children[0].classList.contains('list-group-item') && !membersContainer.children[0].classList.contains('list-group-item-action')) {
                            membersContainer.innerHTML = '';
                        }
                        
                        Array.from(availableUsers).forEach(function(checkbox) {
                            if(checkbox.checked) {
                                let id = checkbox.value;
                                let label = checkbox.nextElementSibling.textContent;
                                let listItem = checkbox.closest('.list-group-item');
                                
                                // Check if member already exists
                                let existingMember = document.querySelector(`input[name="live_members[]"][value="${id}"]`);
                                if(!existingMember) {
                                    let newItem = document.createElement('div');
                                    newItem.className = 'list-group-item list-group-item-action';
                                    
                                    let memberCheckbox = document.createElement('input');
                                    memberCheckbox.type = 'checkbox';
                                    memberCheckbox.name = 'live_members[]';
                                    memberCheckbox.id = `member_${id}`;
                                    memberCheckbox.className = 'form-check-input me-2';
                                    memberCheckbox.value = id;
                                    memberCheckbox.checked = true;
                                    
                                    let memberLabel = document.createElement('label');
                                    memberLabel.htmlFor = `member_${id}`;
                                    memberLabel.className = 'form-check-label';
                                    memberLabel.textContent = label;
                                    
                                    newItem.appendChild(memberCheckbox);
                                    newItem.appendChild(memberLabel);
                                    
                                    membersContainer.appendChild(newItem);
                                    
                                    // Remove from available users list
                                    if(listItem) {
                                        listItem.remove();
                                    }
                                }
                                
                                document.getElementById('selected_users').innerText = 
                                    (parseInt(document.getElementById('selected_users').innerText) || 0) - 1;
                            }
                        });
                        
                        document.getElementById('selectAllAvailable').checked = false;
                        document.getElementById('matriculeID').focus();
                    }
                                            
                        
                    

                    function onScanSuccess(decodedText, decodedResult) {
                        let parts = decodedText.split("_");
                        let id = parts[0];

                        if (id !== lastResult) {
                            ++countResults;
                            lastResult = id;
                            scanSuccess(id, true);
                            document.getElementById('matriculeID').focus();
                        }
                    }

                    function onScanFailure(error) {
                        // Handle scan failure
                    }

                    let html5QrcodeScanner = new Html5QrcodeScanner(
                        "reader",
                        { 
                            fps: 5, 
                            qrbox: {width: 250, height: 250} 
                        },
                        false
                    );
                    
                    html5QrcodeScanner.render(onScanSuccess, onScanFailure);

                    

                    function resetFilters(event) {
                        event.preventDefault();
                        document.getElementById('departments').value = '';
                        document.getElementById('subdepartments').value = '';
                        document.getElementById('locations').value = '';
                        document.querySelector('input[name="search"]').value = '';
                        document.getElementById('thisForm').submit();
                    }

                    function removeParticipant(){
                        let members = document.getElementsByName('live_members[]');
                        let availableContainer = document.querySelector('.list-group');
                        
                        Array.from(members).forEach(function(checkbox) {
                            if(checkbox.checked) {
                                let id = checkbox.value;
                                let label = checkbox.nextElementSibling.textContent;
                                
                                let newItem = document.createElement('div');
                                newItem.className = 'list-group-item list-group-item-action';
                                newItem.innerHTML = `
                                    <input type="checkbox" name="available_users[]" id="available_user_${id}" value="${id}" class="form-check-input me-2" onchange="user_selected()">
                                    <label for="available_user_${id}" class="form-check-label">${label}</label>
                                `;
                                
                                availableContainer.appendChild(newItem);
                                checkbox.parentElement.remove();
                            }
                        });
                        document.getElementById('selectAllMembers').checked = false;
                        document.getElementById('matriculeID').focus();
                    }

                    function sendSubmit(el){
                        let members = document.getElementsByName('live_members[]');
                        
                        if(members.length === 0) {
                            alert('Please select at least one member');
                            return false;
                        }

                        
                        // Check all members and add to request
                        let selectedMembers = [];
                        Array.from(members).forEach(function(checkbox) {
                            checkbox.checked = true;
                            selectedMembers.push(checkbox.value);
                        });
                        // Add members to request
                        let input = document.createElement('input');
                        input.type = 'hidden';
                        input.name = 'live_members';
                        input.value = selectedMembers.join(',');
                        document.getElementById('thisForm').appendChild(input);

                        if(el.id == "reset"){
                            document.getElementById('departments').value = '';
                            document.getElementById('subdepartments').value = '';
                            document.getElementById('locations').value = '';
                        }
                        return true;
                    }

                    codeScanner.addEventListener('keypress', function(e) {
                        if (e.keyCode === 13) {
                            let parts = codeScanner.value.split("_");
                            let id = parts[0];
                            scanSuccess(id, true);
                            codeScanner.value = '';
                        }
                    });

                    form.addEventListener('keypress', function(e) {
                        if (e.keyCode === 13) {
                            e.preventDefault();
                        }
                    });

                    $('.select2').select2();
                </script>
            </div>
        </div>
    </section>
</div>

@endsection
