@extends('layouts.app-bo')
@section('title', __('app.trainers'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="solar:book-bookmark-minimalistic-outline"></iconify-icon>
                            {{ __("app.trainers") }}
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($trainers) }}</b> {{ __('app.items') }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="#" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit" id="create-new-edit">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create") }}
                        </a>
                    </div>
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("app.last_name") }}</th>
                                <th>{{ __("app.first_name") }}</th>
                                <th>{{ __("app.training_institution") }}</th>
                                <th class="table-actions">{{ __("app.actions") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($trainers as $trainer)
                            @php
                            $action = route('trainer.destroy', [$locale]);
                            $id = $trainer->id;
                            $name = $trainer->lname . ' ' . $trainer->fname;
                            $message_question = __('message.confirmation_delete_item');
                            $message_warning = '';
                            @endphp
                            <tr>
                                <td class="table-reference">{{ $trainer->id }}</td>
                                <td>{{ $trainer->lname }}</td>
                                <td>{{ $trainer->fname }}</td>
                                <td>{{ $trainer->training_institution }}</td>
                                <td class="table-actions">
                                    <a href="#" class="text-primary edit form-edit-edit" data-id="{{ $trainer->id }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Modal dialog -->
<form action="{{ route('trainer.store', $locale) }}" method="POST" id="modal-dialog-edit-form">
    @csrf
    <input type="hidden" name="id" id="id" value="" />
    <div id="modal-dialog-edit" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-edit-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-edit-label">
                        {{ __('message.update_trainer') }}
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="row internal-edit">
                        <div class="form-label">
                            <label for="user_ids">{{ __('app.select_trainer_from_existing_users_internal_trainer')}}</label>
                        </div>
                        <div class="form-floating mb-3">
                            <select class="form-select select2" id="user_ids" name="user_ids[]" aria-label="{{ __('app.select_trainer_from_existing_users_internal_trainer') }}" multiple="multiple">
                                @foreach ($trainer_users as $trainer_user)
                                <option value="{{ $trainer_user->id }}">{{ $trainer_user->fname }} {{ $trainer_user->lname }}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="row internal-edit">
                        <div class="col-md-12 form-label">
                            <label>{{ __('app.or_write_name_of_the_new_one_external_trainer')}}</label>
                        </div>
                    </div>
                    <div class="row external-edit">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="lname" name="lname" value="" placeholder="{{ __('app.last_name') }}" />
                                <label for="lname">{{ __('app.last_name') }}</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="fname" name="fname" value="" placeholder="{{ __('app.first_name') }}" />
                                <label for="fname">{{ __('app.first_name') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="training_institution" name="training_institution" value="" placeholder="{{ __('app.training_institution') }}" />
                                <label for="training_institution">{{ __('app.training_institution') }}</label>
                            </div>
                        </div>
                    </div>
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-circle-x fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn bg-primary-subtle text-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Javascript -->
<script type="text/javascript">
    $(function() {
        $("#user_ids").select2({
            dropdownParent: $('#modal-dialog-edit .modal-content')
        });
        $("a#create-new-edit").click(function() {
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.create_trainers') }}");
            $("#modal-dialog-edit-form div.internal-edit").show();
        });

        $("a.form-edit-edit").click(function() {
            $("#modal-dialog-edit-form div.internal-edit").hide();
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.update_trainer') }}");
            $("#modal-dialog-edit-form #id").val("");
            $("#modal-dialog-edit-form #fname").val("");
            $("#modal-dialog-edit-form #lname").val("");
            $("#modal-dialog-edit-form #training_institution").val("");
            var id = $(this).data("id");
            $.ajax({
                url: '{{ route("trainer.get", [$locale]) }}',
                type: 'GET',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: id,
                    model: 'Trainer'
                },
                dataType: 'json',
                success: function(trainer) {
                    if (trainer) {
                        $("#modal-dialog-edit-form #id").val(trainer.id);
                        $("#modal-dialog-edit-form #fname").val(trainer.fname);
                        $("#modal-dialog-edit-form #lname").val(trainer.lname);
                        $("#modal-dialog-edit-form #training_institution").val(trainer.training_institution);
                    }
                }
            });
        });
    });
</script>
@endsection