@extends('layouts.app-bo')
@section('title', __('app.training_categories'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="solar:book-bookmark-minimalistic-outline"></iconify-icon>
                            {{ __("app.training_categories") }}
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($training_categories) }}</b> {{ __('app.items') }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="#" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit" id="create-new-edit">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create") }}
                        </a>
                    </div>
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("app.name") }}</th>
                                <th class="table-actions">{{ __("app.actions") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($training_categories as $training_category)
                            @php
                            $action = route('training-category.destroy', [$locale]);
                            $id = $training_category->id;
                            $name = $training_category->name;
                            $message_question = __('message.confirmation_delete_item');
                            $message_warning = '';
                            @endphp
                            <tr>
                                <td class="table-reference">{{ $training_category->id }}</td>
                                <td>{{ $training_category->name }}</td>
                                <td class="table-actions">
                                    <a href="#" class="text-primary edit form-edit-edit" data-id="{{ $training_category->id }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Modal dialog -->
<form action="{{ route('training-category.store', $locale) }}" method="POST" id="modal-dialog-edit-form" class="needs-validation" novalidate>
    @csrf
    <input type="hidden" name="id" id="id" value="" />
    <div id="modal-dialog-edit" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-edit-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-edit-label">
                        {{ __('message.update_training_category') }}
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="name" name="name" value="" placeholder="{{ __('app.name') }}" required/>
                                <label for="name">{{ __('app.name') }}</label>
                            </div>
                        </div>
                    </div>
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-circle-x fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn bg-primary-subtle text-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Javascript -->
<script type="text/javascript">
    $(function() {
        $("a#create-new-edit").click(function() {
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.create_training_category') }}");
            $("#modal-dialog-edit-form div.internal-edit").show();
        });

        $("a.form-edit-edit").click(function() {
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.update_training_category') }}");
            $("#modal-dialog-edit-form #id").val("");
            $("#modal-dialog-edit-form #name").val("");
            var id = $(this).data("id");
            $.ajax({
                url: '{{ route("training-category.get", [$locale]) }}',
                type: 'GET',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: id,
                    model: 'TrainingCategory'
                },
                dataType: 'json',
                success: function(training_category) {
                    if (training_category) {
                        $("#modal-dialog-edit-form #id").val(training_category.id);
                        $("#modal-dialog-edit-form #name").val(training_category.name);
                    }
                }
            });
        });
    });
</script>
@endsection