@extends('layouts.app-bo')
@section('title', __('app.user_groups'))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="solar:users-group-rounded-broken"></iconify-icon>
                            {{ __("app.user_groups") }}
                        </h4>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="#" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit" id="dialog-create">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create") }}
                        </a>
                    </div>
                </div>
                <div class="mt-3">
                    @if ($groups->total() <= $groups->perPage())
                        <p>{{ __('pagination.Showing') }} {{ $groups->total() }} {{ __('pagination.results') }}</p>
                        @else
                        {{ $groups->appends(request()->query())->links() }}
                        @endif
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference">#</th>
                                <th>{{ __("app.name") }}</th>
                                <th>{{ __("app.description") }}</th>
                                <th>{{ __("app.members") }}</th>
                                <th class="table-actions sticky-search-button">{{ __("app.actions") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($groups as $group)
                            @php
                            $action = route('user-group.destroy', [$locale]);
                            $id = $group->id;
                            $name = $group->name;
                            $message_question = __('message.confirmation_delete_item');
                            $message_warning = '';
                            @endphp
                            <tr>
                                <td class="table-reference">{{ $group->id }}</td>
                                <td>{{ $group->name }}</td>
                                <td>{{ $group->description }}</td>
                                <td nowrap>
                                    @if ($group->users)
                                    <ul>
                                        @foreach ($group->users as $user)
                                        <li>
                                            <i class="ti ti-user fs-4 me-2"></i>
                                            {{ $user->fname }} {{ $user->lname }}
                                        </li>
                                        @endforeach
                                    </ul>
                                    @endif
                                </td>
                                <td class="table-actions sticky-search-button">
                                    <a href="{{ route('user-group.view', [$locale, $group->id]) }}" class="text-primary edit form-edit-edit">
                                        <i class="ti ti-eye fs-5"></i>
                                    </a>
                                    <a href="#" class="text-primary edit form-edit" data-id="{{ $group->id }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-edit">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- Modal dialog -->
<form action="{{ route('user-group.store', $locale) }}" method="POST" id="modal-dialog-edit-form" class="needs-validation" novalidate>
    @csrf
    <input type="hidden" name="id" id="id" value="" />
    <div id="modal-dialog-edit" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-edit-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-edit-label">
                        {{ __('message.create_group') }}
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="name" name="name" value="" placeholder="{{ __('app.name') }}" required />
                                <label for="name">{{ __('app.name') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="description" name="description" placeholder="{{ __('app.description') }}" style="height: 80px;"></textarea>
                                <label for="description">{{ __('app.description') }}</label>
                            </div>
                        </div>
                    </div>
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-circle-x fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn bg-primary-subtle text-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Javascript -->
<script type="text/javascript">
    $(function() {
        $("a#dialog-create").click(function() {
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.create_group') }}");
            $("#modal-dialog-edit-form #id").val("");
            $("#modal-dialog-edit-form #name").val("");
            $("#modal-dialog-edit-form #description").html("");
        });

        $("a.form-edit").click(function() {
            $("#modal-dialog-edit-form #modal-dialog-edit-label").html("{{ __('message.update_group') }}");
            $("#modal-dialog-edit-form #id").val("");
            $("#modal-dialog-edit-form #name").val("");
            $("#modal-dialog-edit-form #description").html("");
            var id = $(this).data("id");
            $.ajax({
                url: '{{ route("user-group.get", [$locale]) }}',
                type: 'GET',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: id,
                    model: 'Group'
                },
                dataType: 'json',
                success: function(group) {
                    if (group) {
                        $("#modal-dialog-edit-form #id").val(group.id);
                        $("#modal-dialog-edit-form #name").val(group.name);
                        $("#modal-dialog-edit-form #description").html(group.description);
                    }
                }
            });
        });
    });
</script>
@endsection