@extends('layouts.app-bo')
@section('title', __('app.user_groups') . ' ' . $group->name)
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card" id="training-demand">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            <iconify-icon icon="solar:users-group-rounded-broken"></iconify-icon>
                            {{ __("app.user_groups") }} : {{ $group->name }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.description') }} : </b> {{ $group->description }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('user-group.list', [$locale]) }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
                <br />
                <form action="{{ route('user-group.view', [$locale, $group->id]) }}" method="GET">
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="department_id" name="department_id" aria-label="{{ __('app.department') }}" onchange="this.form.submit()">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($departments as $department)
                                    <option value="{{ $department->id }}" {{ $department->id == $department_id ? 'selected' : '' }}>{{ $department->name }}</option>
                                    @endforeach
                                </select>
                                <label for="department_id">{{ __('app.department') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="subdepartment_id" name="subdepartment_id" aria-label="{{ __('app.sub_department') }}" onchange="this.form.submit()">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($subdepartments as $subdepartment)
                                    <option value="{{ $subdepartment->id }}" {{ $subdepartment->id == $subdepartment_id ? 'selected' : '' }}>{{ $subdepartment->name }}</option>
                                    @endforeach
                                </select>
                                <label for="subdepartment_id">{{ __ ('app.subdepartment') }}</label>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-floating mb-3 select2-auto-height">
                                <select class="form-select select2" id="location_id" name="location_id" aria-label="{{ __('users.location_division') }}" onchange="this.form.submit()">
                                    <option value="">{{ __('app.select') }} ...</option>
                                    @foreach ($locations as $location)
                                    <option value="{{ $location->id }}" {{ $location->id == $location_id ? 'selected' : '' }}>{{ $location->name }}</option>
                                    @endforeach
                                </select>
                                <label for="location_id">{{ __('users.location_division') }}</label>
                            </div>
                        </div>
                    </div>
                </form>
                <br />
                <form action="{{ route('user-group.store-users', $locale) }}" method="POST" enctype="multipart/form-data">
                    @csrf
                    <input type="hidden" name="id" value="{{ $group->id }}" />
                    <div class="row">
                        <div class="col-md-5 border p-3">
                            <table id="available_users" class="text-nowrap" width="100%">
                                <thead>
                                    <tr>
                                        <th>
                                            <h5 class="mb-3">{{ __('app.available_users') }}</h5>
                                        </th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($available_users as $user)
                                    <tr>
                                        <td>
                                            <input type="checkbox" id="available_users_{{ $user->id }}" name="available_users[{{ $user->id }}]" value="{{ $user->id }}" class="form-check-input">
                                            <label class="form-check-label" for="available_users_{{ $user->id }}">{{ $user->fname }} {{ $user->lname }} [{{ $user->ref }}]</label>
                                        </td>
                                    </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                        <div class="col-md-2 text-center">
                            <br /><br /><br /><br />
                            <button type="submit" name="action" class="btn btn-success" value="add" style="width: 100px;">
                                {{ __('app.add') }}
                                <i class="ti ti-square-arrow-right fs-4"></i>
                            </button>
                            <br /><br />
                            <button type="submit" name="action" class="btn btn-danger" value="remove" style="width: 100px;">
                                <i class="ti ti-square-arrow-left fs-4"></i>
                                {{ __('app.remove') }}
                            </button>
                        </div>
                        <div class="col-md-5 border p-3">
                            <table id="users_in_group" class="text-nowrap" width="100%">
                                <thead>
                                    <tr>
                                        <th>
                                            <h5 class="mb-3">{{ __('app.users_in_group') }}</h5>
                                        </th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($users_in_group as $user)
                                    <tr>
                                        <td>
                                            <input type="checkbox" id="users_in_group_{{ $user->id }}" name="users_in_group[{{ $user->id }}]" value="{{ $user->id }}" class="form-check-input">
                                            <label class="form-check-label" for="users_in_group_{{ $user->id }}">{{ $user->fname }} {{ $user->lname }} [{{ $user->ref }}]</label>
                                        </td>
                                    </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                    <br />
                    <div class="form-actions">
                        <div class="card-body text-center">
                            <a href="{{ route('user-group.list', [$locale]) }}" class="btn btn-primary">
                                <i class="ti ti-check fs-4"></i>
                                {{ __('app.done') }}
                            </a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<script type="text/javascript">
    $(document).ready(function() {
        const config = {
            responsive: true,
            scrollX: true,
            lengthChange: false,
            searching: true,
            paging: false,
            ordering: true,
            info: false,
            order: [
                [0, 'asc']
            ],
            language: {
                search: "",
                searchPlaceholder: "{{ __('app.search_by_name_or_family_name_or_matricule_id') }}"
            }
        };
        set_data_table(config);
    });

    function set_data_table(config) {
        $.noConflict();
        $('#available_users').DataTable(config);
        $('#users_in_group').DataTable(config);
        $('.dataTables_filter label').addClass('w-100');
        $('.dataTables_filter input[type="search"]').addClass('form-control w-100');
    }
</script>
@endsection