@extends('layouts.app-bo')
@section('title', __("app.assign_training_to_user"))
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="text-center">
            <h3>{{ __("app.assign_training_to_user") }}</h3>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-3 mb-md-0">
                        <h4 class="card-title">
                            <strong>{{ __("app.user") }} : </strong> {{ $user->fname }} {{ $user->lname }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b> {{ __('app.category') }} : </b> {{ $category->new_name }}</div>
                    </div>
                    <div class="mb-3 mb-md-0 text-end">
                        <h4 class="card-title">
                            {{ __("app.select_training") }}
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($trainings) }}</b> {{ __('app.items') }}</div>
                    </div>
                </div>
                <br>
                <form action="{{ route('user-training.store', $locale) }}" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    @csrf
                    <input type="hidden" name="user_id" value="{{ $user->id }}" />
                    <div class="{{ $setting->table_div_class }}">
                        <table class="{{ $setting->table_class }}">
                            <thead class="{{ $setting->table_thead_class }}">
                                <tr>
                                    <th class="table-reference">
                                        <div class="form-check">
                                            <input type="checkbox" class="form-check-input" id="training_select_all" title="{{ __('app.select_all') }}" data-bs-toggle="tooltip">
                                        </div>
                                    </th>
                                    <th>{{ __("app.platform") }}</th>
                                    <th>{{ __("app.department") }}</th>
                                    <th>{{ __("app.sub_department") }}</th>
                                    <th>{{ __("app.prefix") }}</th>
                                    <th>{{ __("app.revision") }}</th>
                                    <th>{{ __("app.name") }}</th>
                                </tr>
                            </thead>
                            <tbody class="{{ $setting->table_tbody_class }}">
                                @foreach ($trainings as $training)
                                <tr>
                                    <td class="table-reference">
                                        <div class="form-check">
                                            <input type="checkbox" class="form-check-input training-select" id="training_select_{{ $training->id }}" name="training_id[{{ $training->id }}]" value="{{ $training->id }}" title="{{ $training->name }}" data-bs-toggle="tooltip">
                                        </div>
                                    </td>
                                    <td>{{ $training->platform->type }}</td>
                                    <td>{{ $training->department->name }}</td>
                                    <td>{{ $training->subdepartment->name }}</td>
                                    <td>{{ $training->prefix }}</td>
                                    <td>{{ $training->rev }}</td>
                                    <td>{{ $training->name }}</td>
                                </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                    <div class="alert alert-info text-info mt-4">{{ __('message.note_of_dates_affected_all_selected_trainings') }}</div>
                    <div class="row mt-4">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control @error('start_date') is-invalid @enderror" id="start_date" name="start_date" value="{{ old('start_date') ? : date('Y-m-d') }}" placeholder="{{ __('app.assignment_date') }}" required />
                                <label for="start_date">{{ __('app.assignment_date') }}</label>
                                @error('start_date')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="date" class="form-control @error('end_date') is-invalid @enderror" id="end_date" name="end_date" value="{{ old('end_date') ? : '' }}" placeholder="{{ __('app.due_date') }}" />
                                <label for="end_date">{{ __('app.due_date') }} ({{ __('app.optional') }})</label>
                                @error('end_date')<div class="alert alert-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                    </div>
                    <div class="form-actions">
                        <div class="card-body border-top text-center">
                            <button type="submit" class="btn btn-primary">
                                <i class="ti ti-device-floppy fs-4"></i>
                                {{ __('app.save') }}
                            </button>
                            <a href="{{ route('assign-users.view', [$locale, $user->id]) }}" class="btn bg-danger-subtle text-danger ms-6">
                                <i class="ti ti-circle-x fs-4"></i>
                                {{ __('app.cancel') }}
                            </a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </section>
</div>

<!-- Javascript -->
<script type="text/javascript">
    $(function() {
        $("#training_select_all").click(function() {
            if (this.checked) {
                $("input.training-select").prop("checked", true);
            } else {
                $("input.training-select").prop("checked", false);
            }
        });
    });
</script>
@endsection