@extends('layouts.app-bo')
@section('title', __('app.training') . ' : ' . $training->prefix . ' Rev.' . $training->rev . ' ' . $training->name)
@section('content')

<div class="main-content container-fluid">
    <section class="section">
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __("app.training") }} : {{ $training->prefix . ' Rev.' .  $training->rev . ' ' . $training->name }}
                        </h4>
                        <div class="mb-3 card-subtitle"><b>{{ __('app.category') }} : </b> {{ __('menus.' . $category->code) }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        <a href="{{ route('training.index', [$locale]) . '#' . $category->code }}" class="btn btn-info d-flex align-items-center gap-1 fs-3 py-2 px-9">
                            <i class="ti ti-arrow-back-up fs-4"></i>
                            {{ __("app.back") }}
                        </a>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            @if ($training->category_id != 2)
                            {{ __("app.modules") }}
                            @else
                            {{ __('menus.' . $category->code) }}
                            @endif
                        </h4>
                        <div class="mb-3 card-subtitle">{{ __('app.Total') }} <b>{{ count($modules) }}</b> {{ __('app.items') }}</div>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">
                        @if ($training->category_id != 2)
                        <a href="#" class="btn btn-primary d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-select-module" id="select-module-from-list">
                            <i class="ti ti-circle-plus fs-4"></i>
                            {{ __("app.select_module_from_list") }}
                        </a>
                        <a href="#" class="btn btn-success d-flex align-items-center gap-1 fs-3 py-2 px-9" data-bs-toggle="modal" data-bs-target="#modal-dialog-module" id="create-new-module">
                            <i class="ti ti-plus fs-4"></i>
                            {{ __("app.create_new_module") }}
                        </a>
                        @endif
                    </div>
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}" id="training-module-list">
                        <thead class="{{ $setting->table_thead_class }}">
                            <tr>
                                <th class="table-reference"></th>
                                <th>{{ __("app.name") }}</th>
                                @if ($training->category_id != 2)
                                <th>{{ __("app.type") }}</th>
                                @endif
                                <th class="table-actions">{{ __("app.actions") }}</th>
                            </tr>
                        </thead>
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @php $module_ids = []; @endphp
                            @foreach ($modules as $module)
                            @php
                            $module_ids[$module->id] = $module->id;
                            $action = route('module.destroy', [$locale, $training->id]);
                            $id = $module->id;
                            $name = $module->name;
                            $message_question = __('message.confirm_remove_module');
                            $message_warning = "";
                            @endphp
                            <tr data-id="{{ $module->id }}">
                                <td class="table-reference drag-handle" style="cursor: move;"><i class="ti ti-arrows-up-down fs-5"></i></td>
                                <td>{{ $module->name }}</td>
                                @if ($training->category_id != 2)
                                <td>{{ __('app.' . $module->type) }}</td>
                                @endif
                                <td class="table-actions">
                                    <a href="{{ route('module.view', [$locale, $module->id, $training->id]) }}" class="text-primary view">
                                        <i class="ti ti-eye fs-5"></i>
                                    </a>
                                    <a href="#" class="text-primary edit form-module-edit" data-id="{{ $module->id }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-module">
                                        <i class="ti ti-edit fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-primary delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="d-md-flex align-items-center justify-content-between">
                    <div class="mb-4 mb-md-0">
                        <h4 class="card-title">
                            {{ __("app.attached_documents") }} ({{ count($documents) }})
                        </h4>
                    </div>
                    <div class="d-flex align-items-center justify-content-between gap-6">

                    </div>
                </div>
                <div class="{{ $setting->table_div_class }}">
                    <table class="{{ $setting->table_class }}">
                        <tbody class="{{ $setting->table_tbody_class }}">
                            @foreach ($documents as $document_name => $document_path)
                            @php
                            $link_path = route('other.download', [$locale, $document_name]);
                            $action = route('training.file.delete', [$locale, $document_name]);
                            $id = $training->id;
                            $name = $document_name;
                            $message_question = __('message.training_confirm_delete_file');
                            $message_warning = __('message.training_confirm_delete_file_message');
                            @endphp
                            <tr>
                                <td><a href="{{ $link_path }}">
                                        <h5>{{ $document_name }}</h5>
                                    </a></td>
                                <td class="table-actions">
                                    <a href="{{ $link_path }}" class="text-primary edit">
                                        <i class="ti ti-download fs-5"></i>
                                    </a>
                                    <a href="#" onclick="set_data_delete('{{ $action }}', '{{ $id }}', '{{ $name }}', '{{ $message_warning }}', '{{ $message_question }}')" data-bs-toggle="modal" data-bs-target="#modal-dialog-delete" class="text-danger delete">
                                        <i class="ti ti-trash fs-5"></i>
                                    </a>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <div class="form-action">
            <div class="card-body text-center">
                <a href="{{ route('training.index', [$locale]) . '#' . $category->code }}" class="btn btn-info ms-6">
                    <i class="ti ti-arrow-back-up fs-4"></i>
                    {{ __("app.back") }}
                </a>
                <a href="#" class="btn btn-success ms-6" data-id="{{ $training->id }}" data-name="{{ $training->name }}" data-bs-toggle="modal" data-bs-target="#modal-dialog-training-confirmation-enable" onclick="open_dialig_enable(this)">
                    <i class="ti ti-clipboard-check fs-4"></i>
                    {{ __('app.enable_training_and_go_to_trainings') }}
                </a>
            </div>
        </div>
        <br />
        <br />
        <br />
    </section>
</div>

<!-- Modal dialog module -->
<form action="{{ route('module.store', $locale) }}" method="POST" id="modal-dialog-module-form">
    @csrf
    <input type="hidden" name="id" id="id" value="" />
    <input type="hidden" name="training_id" value="{{ $training->id }}" />
    <input type="hidden" name="category_id" value="{{ $training->category_id }}" />
    <div id="modal-dialog-module" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-module-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-primary text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-module-label">
                        {{ __('message.create_modules') }}
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="name" name="name" value="" placeholder="{{ __('app.name') }}" required />
                                <label for="name">{{ __('app.name') }}</label>
                            </div>
                        </div>
                    </div>
                    @if ($training->category_id != 2)
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-floating mb-3">
                                <select class="form-select" id="type" name="type" aria-label="{{ __('app.type') }}">
                                    <option value="Theory / Exercises">{{ __('app.theory_exercises') }}</option>
                                    <option value="Exam">{{ __('app.exam') }}</option>
                                </select>
                                <label for="type">{{ __('app.type') }}</label>
                            </div>
                        </div>
                    </div>
                    <div class="row" id="div-type">
                        <div class="col-md-12">
                            <div class="form-check">
                                <label class="form-check-label" for="scorm_quiz">{{ __('app.scorm_quiz') }}
                                    <input type="checkbox" class="form-check-input" id="scorm_quiz" name="scorm_quiz" value="1" placeholder="{{ __('app.scorm_quiz') }} }}">
                                </label>
                            </div>
                        </div>
                    </div>
                    @endif
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-circle-x fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn bg-primary-subtle text-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Modal dialog select module -->
<form action="{{ route('training.module.duplicate', $locale) }}" method="POST" id="modal-dialog-select-module-form">
    @csrf
    <input type="hidden" name="training_id" value="{{ $training->id }}" />
    <div id="modal-dialog-select-module" class="modal fade" tabindex="-1" aria-labelledby="modal-dialog-select-module-label" aria-hidden="true">
        <div class="modal-dialog modal-dialog-scrollable modal-lg">
            <div class="modal-content">
                <div class="modal-header modal-colored-header bg-info text-white">
                    <h4 class="modal-title text-white" id="modal-dialog-select-module-label">
                        {{ __('message.add_modules_to_training') }} :
                        {{ $training->prefix . ' Rev.' . $training->rev . ' ' . $training->name }}
                    </h4>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="alert alert-warning text-warning">{{ __('message.selecting_module_affect_source') }}</div>
                    <div class="{{ $setting->table_div_class }}">
                        <table class="{{ $setting->table_class }}">
                            <thead class="{{ $setting->table_thead_class }}">
                                <tr>
                                    <th class="table-reference">
                                        <div class="form-check">
                                            <input type="checkbox" class="form-check-input" id="module_select_all" title="{{ __('app.select_all') }}" data-bs-toggle="tooltip">
                                        </div>
                                    </th>
                                    <th>{{ __("app.name") }}</th>
                                    <th>{{ __("app.type") }}</th>
                                </tr>
                            </thead>
                            <tbody class="{{ $setting->table_tbody_class }}">
                                @foreach ($all_modules as $module)
                                <tr>
                                    <td class="table-reference">
                                        <div class="form-check">
                                            <!-- <input type="checkbox" class="form-check-input module-select" id="module_select_{{ $module->id }}" name="module_id[{{ $module->id }}]" value="{{ $module->id }}" title="{{ $module->name }}" data-bs-toggle="tooltip" {{ in_array($module->id, $module_ids) ? 'checked' : '' }}> -->
                                            <input type="checkbox" class="form-check-input module-select" id="module_select_{{ $module->id }}" name="module_id[{{ $module->id }}]" value="{{ $module->id }}" title="{{ $module->name }}" data-bs-toggle="tooltip">
                                        </div>
                                    </td>
                                    <td>{{ $module->name }}</td>
                                    <td>{{ $module->type }}</td>
                                </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
                <hr />
                <div class="modal-footer">
                    <button type="button" class="btn btn-light" data-bs-dismiss="modal">
                        <i class="ti ti-circle-x fs-4"></i>
                        {{ __('app.cancel') }}
                    </button>
                    <button type="submit" class="btn bg-primary-subtle text-primary">
                        <i class="ti ti-device-floppy fs-4"></i>
                        {{ __('app.save') }}
                    </button>
                </div>
            </div>
        </div>
    </div>
</form>

<!-- Javascript -->
<script type="text/javascript">
    $(function() {
        $("form#modal-dialog-module-form select#type").change(function() {
            var type = $(this).val();
            if (type == "Exam") {
                $("form#modal-dialog-module-form div#div-type").fadeIn().show();
            } else {
                $("form#modal-dialog-module-form div#div-type").fadeOut().hide();
            }
        }).change();

        $("#modal-dialog-select-module #module_select_all").click(function() {
            if (this.checked) {
                $("#modal-dialog-select-module .module-select").prop("checked", true);
            } else {
                $("#modal-dialog-select-module .module-select").prop("checked", false);
            }
        });

        $("a#create-new-module").click(function() {
            $("#modal-dialog-module-form #modal-dialog-module-label").html("{{ __('message.create_modules') }}");
        });

        $("a.form-module-edit").click(function() {
            $("#modal-dialog-module-form #modal-dialog-module-label").html("{{ __('message.update_modules') }}");
            $("#modal-dialog-module-form #id").val("");
            $("#modal-dialog-module-form #name").val("");
            $("#modal-dialog-module-form #type").val("");
            var id = $(this).data("id");
            $.ajax({
                url: '{{ route("module.get", [$locale]) }}',
                type: 'GET',
                data: {
                    _token: '{{ csrf_token() }}',
                    id: id,
                    model: 'Module'
                },
                dataType: 'json',
                success: function(module) {
                    if (module) {
                        $("#modal-dialog-module-form #id").val(module.id);
                        $("#modal-dialog-module-form #name").val(module.name);
                        $("#modal-dialog-module-form #type").val(module.type);
                        $("form#modal-dialog-module-form select#type").change();
                        if (module.scorm_quiz) {
                            $("#modal-dialog-module-form #scorm_quiz").prop("checked", true);
                        } else {
                            $("#modal-dialog-module-form #scorm_quiz").prop("checked", false);
                        }
                    }
                }
            });
        });

        $("table#training-module-list tbody").sortable({
            handle: ".drag-handle",
            items: "tr",
            cursor: "move",
            placeholder: "ui-state-highlight",
            start: function(e, ui) {
                ui.placeholder.height(ui.item.height());
            },
            update: function(event, ui) {
                var elements = $(this).sortable('toArray', {
                    attribute: 'data-id'
                });
                $.ajax({
                    url: '{{ route("module.update.order", [$locale]) }}',
                    type: 'POST',
                    data: {
                        _token: '{{ csrf_token() }}',
                        training_id: '{{ $training->id }}',
                        ids: elements
                    },
                    dataType: 'json',
                    success: function() {
                        toastr.success(
                            "success",
                            "{{ __('message.order_updated') }}", {
                                showMethod: "fadeIn",
                                hideMethod: "fadeOut",
                                timeOut: 1000,
                                closeButton: true
                            }
                        );
                    }
                });
            }
        });
        $("#table#training-module-list tbody").disableSelection();
    });
</script>

@include('lib.training-confirm-dialog')

@endsection